"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsTextItem(QGraphicsObject):
    """
    https://doc.qt.io/qt-6/qgraphicstextitem.html

    **Detailed Description**

    If you only need to show plain text in an item, consider using
    **QGraphicsSimpleTextItem**  instead.

    To set the item's text, pass a **QString**  to QGraphicsTextItem's
    constructor, or call **setHtml** ()/**setPlainText** ().

    QGraphicsTextItem uses the text's formatted size and the associated font to
    provide a reasonable implementation of **boundingRect** (), **shape** (),
    and **contains** (). You can set the font by calling **setFont** ().

    It is possible to make the item editable by setting the
    **Qt::TextEditorInteraction**  flag using **setTextInteractionFlags** ().

    The item's preferred text width can be set using **setTextWidth** () and
    obtained using **textWidth** ().

    **Note:** In order to align HTML text in the center, the item's text width
    must be set. Otherwise, you can call **adjustSize** () after setting the
    item's text.

    ![](images/graphicsview-textitem.png)

    **Note:** QGraphicsTextItem accepts **hover events**  by default. You can
    change this with **setAcceptHoverEvents** ().

    **See also** **QGraphicsSimpleTextItem** , **QGraphicsPathItem** ,
    **QGraphicsRectItem** , **QGraphicsEllipseItem** , **QGraphicsPixmapItem** ,
    **QGraphicsPolygonItem** , **QGraphicsLineItem** , and **Graphics View
    Framework** .
    """

    @typing.overload
    def __init__(self, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#QGraphicsTextItem

        **QGraphicsTextItem::QGraphicsTextItem(QGraphicsItem * parent =
        nullptr)**

        Constructs a QGraphicsTextItem. **parent** is passed to
        **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    @typing.overload
    def __init__(self, text: str, parent: typing.Optional[QGraphicsItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#QGraphicsTextItem-1

        **QGraphicsTextItem::QGraphicsTextItem(const QString & text ,
        QGraphicsItem * parent = nullptr)**

        Constructs a QGraphicsTextItem, using **text** as the default plain
        text. **parent** is passed to **QGraphicsItem** 's constructor.

        **See also** **QGraphicsScene::addItem** ().
        """
        ...

    def inputMethodQuery(self, query: QtCore.Qt.InputMethodQuery) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#inputMethodQuery

        **[override virtual protected] QVariant
        QGraphicsTextItem::inputMethodQuery(Qt::InputMethodQuery query ) const**

        Reimplements: **QGraphicsItem::inputMethodQuery(Qt::InputMethodQuery
        query) const** .
        """
        ...

    def hoverLeaveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#hoverLeaveEvent

        **[override virtual protected] void
        QGraphicsTextItem::hoverLeaveEvent(QGraphicsSceneHoverEvent * event )**

        Reimplements: **QGraphicsItem::hoverLeaveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def hoverMoveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#hoverMoveEvent

        **[override virtual protected] void
        QGraphicsTextItem::hoverMoveEvent(QGraphicsSceneHoverEvent * event )**

        Reimplements: **QGraphicsItem::hoverMoveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def hoverEnterEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#hoverEnterEvent

        **[override virtual protected] void
        QGraphicsTextItem::hoverEnterEvent(QGraphicsSceneHoverEvent * event )**

        Reimplements: **QGraphicsItem::hoverEnterEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def inputMethodEvent(self, event: QtGui.QInputMethodEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#inputMethodEvent

        **[override virtual protected] void
        QGraphicsTextItem::inputMethodEvent(QInputMethodEvent * event )**

        Reimplements: **QGraphicsItem::inputMethodEvent** (QInputMethodEvent
        *event).
        """
        ...

    def dropEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#dropEvent

        **[override virtual protected] void
        QGraphicsTextItem::dropEvent(QGraphicsSceneDragDropEvent * event )**

        Reimplements: **QGraphicsItem::dropEvent** (QGraphicsSceneDragDropEvent
        *event).
        """
        ...

    def dragMoveEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#dragMoveEvent

        **[override virtual protected] void
        QGraphicsTextItem::dragMoveEvent(QGraphicsSceneDragDropEvent * event )**

        Reimplements: **QGraphicsItem::dragMoveEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def dragLeaveEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#dragLeaveEvent

        **[override virtual protected] void
        QGraphicsTextItem::dragLeaveEvent(QGraphicsSceneDragDropEvent * event
        )**

        Reimplements: **QGraphicsItem::dragLeaveEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def dragEnterEvent(self, event: "QGraphicsSceneDragDropEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#dragEnterEvent

        **[override virtual protected] void
        QGraphicsTextItem::dragEnterEvent(QGraphicsSceneDragDropEvent * event
        )**

        Reimplements: **QGraphicsItem::dragEnterEvent**
        (QGraphicsSceneDragDropEvent *event).
        """
        ...

    def focusOutEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#focusOutEvent

        **[override virtual protected] void
        QGraphicsTextItem::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsItem::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusInEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#focusInEvent

        **[override virtual protected] void
        QGraphicsTextItem::focusInEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsItem::focusInEvent** (QFocusEvent *event).
        """
        ...

    def keyReleaseEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#keyReleaseEvent

        **[override virtual protected] void
        QGraphicsTextItem::keyReleaseEvent(QKeyEvent * event )**

        Reimplements: **QGraphicsItem::keyReleaseEvent** (QKeyEvent *event).
        """
        ...

    def keyPressEvent(self, event: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#keyPressEvent

        **[override virtual protected] void
        QGraphicsTextItem::keyPressEvent(QKeyEvent * event )**

        Reimplements: **QGraphicsItem::keyPressEvent** (QKeyEvent *event).
        """
        ...

    def contextMenuEvent(self, event: "QGraphicsSceneContextMenuEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#contextMenuEvent

        **[override virtual protected] void
        QGraphicsTextItem::contextMenuEvent(QGraphicsSceneContextMenuEvent *
        event )**

        Reimplements: **QGraphicsItem::contextMenuEvent**
        (QGraphicsSceneContextMenuEvent *event).
        """
        ...

    def mouseDoubleClickEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QGraphicsTextItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *
        event )**

        Reimplements: **QGraphicsItem::mouseDoubleClickEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mouseReleaseEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#mouseReleaseEvent

        **[override virtual protected] void
        QGraphicsTextItem::mouseReleaseEvent(QGraphicsSceneMouseEvent * event
        )**

        Reimplements: **QGraphicsItem::mouseReleaseEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mouseMoveEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#mouseMoveEvent

        **[override virtual protected] void
        QGraphicsTextItem::mouseMoveEvent(QGraphicsSceneMouseEvent * event )**

        Reimplements: **QGraphicsItem::mouseMoveEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def mousePressEvent(self, event: "QGraphicsSceneMouseEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#mousePressEvent

        **[override virtual protected] void
        QGraphicsTextItem::mousePressEvent(QGraphicsSceneMouseEvent * event )**

        Reimplements: **QGraphicsItem::mousePressEvent**
        (QGraphicsSceneMouseEvent *event).
        """
        ...

    def sceneEvent(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#sceneEvent

        **[override virtual protected] bool QGraphicsTextItem::sceneEvent(QEvent
        * event )**

        Reimplements: **QGraphicsItem::sceneEvent** (QEvent *event).
        """
        ...

    def textCursor(self) -> QtGui.QTextCursor:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#textCursor-prop

        **textCursor : QTextCursor**

        This property represents the visible text cursor in an editable text
        item.

        By default, if the item's text has not been set, this property contains
        a null text cursor; otherwise it contains a text cursor placed at the
        start of the item's document.

        **Access functions:**

        QTextCursor **textCursor** () const
        void **setTextCursor** (const
        QTextCursor & **cursor** )

        **Member Function Documentation**
        """
        ...

    def setTextCursor(self, cursor: QtGui.QTextCursor) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#textCursor-prop

        **textCursor : QTextCursor**

        This property represents the visible text cursor in an editable text
        item.

        By default, if the item's text has not been set, this property contains
        a null text cursor; otherwise it contains a text cursor placed at the
        start of the item's document.

        **Access functions:**

        QTextCursor **textCursor** () const
        void **setTextCursor** (const
        QTextCursor & **cursor** )

        **Member Function Documentation**
        """
        ...

    def openExternalLinks(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QGraphicsTextItem**  should automatically open links
        using **QDesktopServices::openUrl** () instead of emitting the
        **linkActivated**  signal.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )
        """
        ...

    def setOpenExternalLinks(self, open: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#openExternalLinks-prop

        **openExternalLinks : bool**

        Specifies whether **QGraphicsTextItem**  should automatically open links
        using **QDesktopServices::openUrl** () instead of emitting the
        **linkActivated**  signal.

        The default value is false.

        **Access functions:**

        bool **openExternalLinks** () const
        void **setOpenExternalLinks**
        (bool **open** )
        """
        ...

    def tabChangesFocus(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#tabChangesFocus

        **bool QGraphicsTextItem::tabChangesFocus() const**

        Returns `true` if the **Tab** key will cause the widget to change focus;
        otherwise, false is returned.

        By default, this behavior is disabled, and this function will return
        false.

        **See also** **setTabChangesFocus** ().
        """
        ...

    def setTabChangesFocus(self, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setTabChangesFocus

        **void QGraphicsTextItem::setTabChangesFocus(bool b )**

        If **b** is true, the **Tab** key will cause the widget to change focus;
        otherwise, the tab key will insert a tab into the document.

        In some occasions text edits should not allow the user to input
        tabulators or change indentation using the **Tab** key, as this breaks
        the focus chain. The default is false.

        **See also** **tabChangesFocus** (), **ItemIsFocusable** , and
        **textInteractionFlags** ().
        """
        ...

    def textInteractionFlags(self) -> QtCore.Qt.TextInteractionFlag:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#textInteractionFlags

        **Qt::TextInteractionFlags QGraphicsTextItem::textInteractionFlags()
        const**

        Returns the current text interaction flags.

        **See also** **setTextInteractionFlags** ().
        """
        ...

    def setTextInteractionFlags(self, flags: QtCore.Qt.TextInteractionFlag) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setTextInteractionFlags

        **void
        QGraphicsTextItem::setTextInteractionFlags(Qt::TextInteractionFlags
        flags )**

        Sets the flags **flags** to specify how the text item should react to
        user input.

        The default for a **QGraphicsTextItem**  is **Qt::NoTextInteraction** .
        This function also affects the ItemIsFocusable **QGraphicsItem**  flag
        by setting it if **flags** is different from **Qt::NoTextInteraction**
        and clearing it otherwise.

        By default, the text is read-only. To transform the item into an editor,
        set the **Qt::TextEditable**  flag.

        **See also** **textInteractionFlags** ().
        """
        ...

    def document(self) -> QtGui.QTextDocument:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#document

        **QTextDocument *QGraphicsTextItem::document() const**

        Returns the item's text document.

        **See also** **setDocument** ().
        """
        ...

    def setDocument(self, document: QtGui.QTextDocument) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setDocument

        **void QGraphicsTextItem::setDocument(QTextDocument * document )**

        Sets the text document **document** on the item.

        **See also** **document** ().
        """
        ...

    def adjustSize(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#adjustSize

        **void QGraphicsTextItem::adjustSize()**

        Adjusts the text item to a reasonable size.
        """
        ...

    def textWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#textWidth

        **qreal QGraphicsTextItem::textWidth() const**

        Returns the text width.

        The width is calculated with the **QTextDocument**  that
        **QGraphicsTextItem**  keeps internally.

        **See also** **setTextWidth** () and **QTextDocument::textWidth** ().
        """
        ...

    def setTextWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setTextWidth

        **void QGraphicsTextItem::setTextWidth(qreal width )**

        Sets the preferred width for the item's text. If the actual text is
        wider than the specified width then it will be broken into multiple
        lines.

        If **width** is set to -1 then the text will not be broken into multiple
        lines unless it is enforced through an explicit line break or a new
        paragraph.

        The default value is -1.

        Note that **QGraphicsTextItem**  keeps a **QTextDocument**  internally,
        which is used to calculate the text width.

        **See also** **textWidth** () and **QTextDocument::setTextWidth** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#type

        **[override virtual] int QGraphicsTextItem::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def opaqueArea(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#opaqueArea

        **[override virtual] QPainterPath QGraphicsTextItem::opaqueArea()
        const**

        Reimplements: **QGraphicsItem::opaqueArea() const** .
        """
        ...

    def isObscuredBy(self, item: QGraphicsItem) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#isObscuredBy

        **[override virtual] bool QGraphicsTextItem::isObscuredBy(const
        QGraphicsItem * item ) const**

        Reimplements: **QGraphicsItem::isObscuredBy(const QGraphicsItem *item)
        const** .
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: QWidget,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#paint

        **[override virtual] void QGraphicsTextItem::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget )**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def contains(self, point: QtCore.QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#contains

        **[override virtual] bool QGraphicsTextItem::contains(const QPointF &
        point ) const**

        Reimplements: **QGraphicsItem::contains(const QPointF &point) const** .
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#shape

        **[override virtual] QPainterPath QGraphicsTextItem::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#boundingRect

        **[override virtual] QRectF QGraphicsTextItem::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def defaultTextColor(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#defaultTextColor

        **QColor QGraphicsTextItem::defaultTextColor() const**

        Returns the default text color that is used for unformatted text.

        **See also** **setDefaultTextColor** ().
        """
        ...

    def setDefaultTextColor(
        self, c: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setDefaultTextColor

        **void QGraphicsTextItem::setDefaultTextColor(const QColor & col )**

        Sets the color for unformatted text to **col**.

        **See also** **defaultTextColor** ().
        """
        ...

    def setFont(self, font: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setFont

        **void QGraphicsTextItem::setFont(const QFont & font )**

        Sets the font used to render the text item to **font**.

        **See also** **font** ().
        """
        ...

    def font(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#font

        **QFont QGraphicsTextItem::font() const**

        Returns the item's font, which is used to render the text.

        **See also** **setFont** ().
        """
        ...

    def setPlainText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setPlainText

        **void QGraphicsTextItem::setPlainText(const QString & text )**

        Sets the item's text to **text**. If the item has keyboard input focus,
        this function will also call **ensureVisible** () to ensure that the
        text is visible in all viewports.

        **See also** **toHtml** () and **hasFocus** ().
        """
        ...

    def toPlainText(self) -> str:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#toPlainText

        **QString QGraphicsTextItem::toPlainText() const**

        Returns the item's text converted to plain text, or an empty **QString**
        if no text has been set.

        **See also** **setPlainText** ().
        """
        ...

    def setHtml(self, html: str) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#setHtml

        **void QGraphicsTextItem::setHtml(const QString & text )**

        Sets the item's text to **text** , assuming that text is HTML formatted.
        If the item has keyboard input focus, this function will also call
        **ensureVisible** () to ensure that the text is visible in all
        viewports.

        **See also** **toHtml** (), **hasFocus** (), and
        **QGraphicsSimpleTextItem** .
        """
        ...

    def toHtml(self) -> str:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#toHtml

        **QString QGraphicsTextItem::toHtml() const**

        Returns the item's text converted to HTML, or an empty **QString**  if
        no text has been set.

        **See also** **setHtml** ().
        """
        ...

    @property
    def linkActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#linkActivated

        **[signal] void QGraphicsTextItem::linkActivated(const QString & link
        )**

        This signal is emitted when the user clicks on a link on a text item
        that enables **Qt::LinksAccessibleByMouse**  or
        **Qt::LinksAccessibleByKeyboard** . **link** is the link that was
        clicked.

        **See also** **setTextInteractionFlags** ().
        """
        ...

    @property
    def linkHovered(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicstextitem.html#linkHovered

        **[signal] void QGraphicsTextItem::linkHovered(const QString & link )**

        This signal is emitted when the user hovers over a link on a text item
        that enables **Qt::LinksAccessibleByMouse** . **link** is the link that
        was hovered over.

        **See also** **setTextInteractionFlags** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore


class QRemoteObjectAbstractPersistedStore(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qremoteobjectabstractpersistedstore.html

    **Detailed Description**

    This can be used to provide a "reasonable" value to be displayed until the
    connection to the source is established and current values are available.

    This class must be overridden to provide an implementation for saving
    (**QRemoteObjectAbstractPersistedStore::saveProperties** ) and restoring
    (**QRemoteObjectAbstractPersistedStore::restoreProperties** ) PROP values.
    The derived type can then be set for a node, and any replica acquired from
    that node will then automatically store PERSISTED properties when the
    replica destructor is called, and retrieve the values when the replica is
    instantiated.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectabstractpersistedstore.html#QRemoteO
        bjectAbstractPersistedStore

        **QRemoteObjectAbstractPersistedStore::QRemoteObjectAbstractPersistedSto
        re(QObject * parent = nullptr)**

        Constructs a QRemoteObjectAbstractPersistedStore with the given
        **parent**. The default value of **parent** is `nullptr`.
        """
        ...

    def restoreProperties(
        self, repName: str, repSig: QtCore.QByteArray
    ) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qremoteobjectabstractpersistedstore.html#restoreP
        roperties

        **[pure virtual] QVariantList
        QRemoteObjectAbstractPersistedStore::restoreProperties(const QString &
        repName , const QByteArray & repSig )**

        This method will be provided the replica class's **repName** and
        **repSig** when the replica is being initialized. It is the
        responsibility of the inheriting class to get the last values persisted
        by **QRemoteObjectAbstractPersistedStore::saveProperties**  and return
        them. An empty QVariantList should be returned if no values are
        available.

        **See also** **QRemoteObjectAbstractPersistedStore::saveProperties** .
        """
        ...

    def saveProperties(
        self,
        repName: str,
        repSig: QtCore.QByteArray,
        values: typing.Iterable[typing.Any],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qremoteobjectabstractpersistedstore.html#saveProp
        erties

        **[pure virtual] void
        QRemoteObjectAbstractPersistedStore::saveProperties(const QString &
        repName , const QByteArray & repSig , const QVariantList & values )**

        This method will be provided the replica class's **repName** ,
        **repSig** and the list of **values** that PERSISTED properties have
        when the replica destructor was called. It is the responsibility of the
        inheriting class to store the information in a manner consistent for
        **QRemoteObjectAbstractPersistedStore::restoreProperties**  to retrieve.

        **See also** **QRemoteObjectAbstractPersistedStore::restoreProperties**
        .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QBluetoothLocalDevice(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qbluetoothlocaldevice.html

    **Detailed Description**

    QBluetoothLocalDevice provides functions for getting and setting the state
    of local Bluetooth devices.

    On iOS and Windows, this class cannot be used because the platform does not
    expose any data or API which may provide information on the local Bluetooth
    device.
    """

    class Error(enum.Enum):
        NoError: QBluetoothLocalDevice = ...
        PairingError: QBluetoothLocalDevice = ...
        UnknownError: QBluetoothLocalDevice = ...

    class HostMode(enum.Enum):
        HostPoweredOff: QBluetoothLocalDevice = ...
        HostConnectable: QBluetoothLocalDevice = ...
        HostDiscoverable: QBluetoothLocalDevice = ...
        HostDiscoverableLimitedInquiry: QBluetoothLocalDevice = ...

    class Pairing(enum.Enum):
        Unpaired: QBluetoothLocalDevice = ...
        Paired: QBluetoothLocalDevice = ...
        AuthorizedPaired: QBluetoothLocalDevice = ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#QBluetoothLocalDevice

        **QBluetoothLocalDevice::QBluetoothLocalDevice(QObject * parent =
        nullptr)**

        Constructs a QBluetoothLocalDevice with **parent**.
        """
        ...

    @typing.overload
    def __init__(
        self, address: QBluetoothAddress, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#QBluetoothLocalDevice-
        1

        **QBluetoothLocalDevice::QBluetoothLocalDevice(const QBluetoothAddress &
        address , QObject * parent = 0)**

        Construct new QBluetoothLocalDevice for **address**. If **address** is
        default constructed the resulting local device selects the local default
        device.
        """
        ...

    def connectedDevices(self) -> typing.List[QBluetoothAddress]:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#connectedDevices

        **[since 5.3] QList<QBluetoothAddress>
        QBluetoothLocalDevice::connectedDevices() const**

        Returns the list of connected devices. This list is different from the
        list of currently paired devices.

        On Android and macOS, it is not possible to retrieve a list of connected
        devices. It is only possible to listen to (dis)connect changes. For
        convenience, this class monitors all connect and disconnect events since
        its instanciation and returns the current list when calling this
        function. Therefore it is possible that this function returns an empty
        list shortly after creating an instance.

        This function was introduced in Qt 5.3.

        **See also** **deviceConnected** () and **deviceDisconnected** ().
        """
        ...

    @staticmethod
    def allDevices() -> typing.List[QBluetoothHostInfo]:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#allDevices

        **[static] QList<QBluetoothHostInfo>
        QBluetoothLocalDevice::allDevices()**

        Returns a list of all available local Bluetooth devices. On macOS, there
        is only the "default" local device.
        """
        ...

    def address(self) -> QBluetoothAddress:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#address

        **QBluetoothAddress QBluetoothLocalDevice::address() const**

        Returns the MAC address of this Bluetooth device.

        **Note:** On Android, this function always returns the constant value
        `02:00:00:00:00:00` as local address starting with Android 6.0. The
        programmatic access to the device's local MAC address was removed.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#name

        **QString QBluetoothLocalDevice::name() const**

        Returns the name assgined by the user to this Bluetooth device.
        """
        ...

    def powerOn(self) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#powerOn

        **void QBluetoothLocalDevice::powerOn()**

        Powers on the device after returning it to the **hostMode** () state, if
        it was powered off.

        **Note:** Due to varying security policies on the supported platforms,
        this method may have differing behaviors on the various platforms. For
        example the system may ask the user for confirmation before turning
        Bluetooth on or off. On macOS it is not possible to power on/off
        Bluetooth. Please refer to the platform specific Bluetooth documentation
        for details.
        """
        ...

    def hostMode(self) -> "QBluetoothLocalDevice.HostMode":
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#hostMode

        **QBluetoothLocalDevice::HostMode QBluetoothLocalDevice::hostMode()
        const**

        Returns the current host mode of this local Bluetooth device. On macOS,
        it is either **HostPoweredOff**  or **HostConnectable** .

        **See also** **setHostMode** ().
        """
        ...

    def setHostMode(self, mode: "QBluetoothLocalDevice.HostMode") -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#setHostMode

        **void
        QBluetoothLocalDevice::setHostMode(QBluetoothLocalDevice::HostMode mode
        )**

        Sets the host mode of this local Bluetooth device to **mode**.

        Some transitions such as turning the device on or off may take some
        time. Therefore subsequent calls should only be made once the
        **hostModeStateChanged** () signal has concluded the previous request.
        If this is ignored the result of such a series of calls is not well
        defined.

        **Note:** Due to varying security policies on the supported platforms,
        this method may have differing behaviors on the various platforms. For
        example the system may ask the user for confirmation before turning
        Bluetooth on or off and not all host modes may be supported. On macOS,
        it is not possbile to programmatically change the **hostMode** (). A
        user can only switch Bluetooth on/off in the System Preferences. Please
        refer to the platform specific Bluetooth documentation for details.

        **See also** **hostMode** ().
        """
        ...

    def pairingStatus(
        self, address: QBluetoothAddress
    ) -> "QBluetoothLocalDevice.Pairing":
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#pairingStatus

        **QBluetoothLocalDevice::Pairing
        QBluetoothLocalDevice::pairingStatus(const QBluetoothAddress & address )
        const**

        Returns the current bluetooth pairing status of **address** , if it's
        unpaired, paired, or paired and authorized.
        """
        ...

    def requestPairing(
        self, address: QBluetoothAddress, pairing: "QBluetoothLocalDevice.Pairing"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#requestPairing

        **void QBluetoothLocalDevice::requestPairing(const QBluetoothAddress &
        address , QBluetoothLocalDevice::Pairing pairing )**

        Set the **pairing** status with **address**. The results are returned by
        the signal, **pairingFinished** (). On Android and macOS,
        **AuthorizedPaired**  is not possible and will have the same behavior as
        Paired.

        On macOS, it is not possible to unpair a device. If Unpaired is
        requested, **pairingFinished** () is immediately emitted although the
        device remains paired. It is possible to request the pairing for a
        previously unpaired device. In addition **AuthorizedPaired**  has the
        same behavior as **Paired** .

        Caution: creating a pairing may take minutes, and may require the user
        to acknowledge.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#isValid

        **bool QBluetoothLocalDevice::isValid() const**

        Returns `true` if the **QBluetoothLocalDevice**  represents an available
        local Bluetooth device; otherwise return false.

        If the local Bluetooth adapter represented by an instance of this class
        is removed from the system (e.g. removal of the underlying Bluetooth
        dongle) then this instance will become invalid. An already invalid
        **QBluetoothLocalDevice**  instance remains invalid even if the same
        Bluetooth adapter is returned to the system.

        **See also** **allDevices** ().
        """
        ...

    @property
    def deviceConnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#deviceConnected

        **[signal, since 5.3] void QBluetoothLocalDevice::deviceConnected(const
        QBluetoothAddress & address )**

        This signal is emitted when the local device establishes a connection to
        a remote device with **address**.

        This function was introduced in Qt 5.3.

        **See also** **deviceDisconnected** () and **connectedDevices** ().
        """
        ...

    @property
    def deviceDisconnected(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#deviceDisconnected

        **[signal, since 5.3] void
        QBluetoothLocalDevice::deviceDisconnected(const QBluetoothAddress &
        address )**

        This signal is emitted when the local device disconnects from a remote
        Bluetooth device with **address**.

        This function was introduced in Qt 5.3.

        **See also** **deviceConnected** () and **connectedDevices** ().
        """
        ...

    @property
    def errorOccurred(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#errorOccurred

        **[signal, since 6.2] void
        QBluetoothLocalDevice::errorOccurred(QBluetoothLocalDevice::Error error
        )**

        Signal emitted if there's an exceptional **error** while pairing.

        This function was introduced in Qt 6.2.
        """
        ...

    @property
    def hostModeStateChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#hostModeStateChanged

        **[signal] void QBluetoothLocalDevice::hostModeStateChanged(QBluetoothLo
        calDevice::HostMode state )**

        The **state** of the host has transitioned to a different **HostMode** .
        """
        ...

    @property
    def pairingFinished(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qbluetoothlocaldevice.html#pairingFinished

        **[signal] void QBluetoothLocalDevice::pairingFinished(const
        QBluetoothAddress & address , QBluetoothLocalDevice::Pairing pairing )**

        Pairing or unpairing has completed with **address**. Current pairing
        status is in **pairing**. If the pairing request was not successful,
        this signal will not be emitted. The **errorOccurred** () signal is
        emitted if the pairing request failed. The signal is only ever emitted
        for pairing requests which have previously requested by calling
        **requestPairing** () of the current object instance.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
import datetime
from PyQt6.QtPositioning import *


class QGeoAreaMonitorInfo(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeoareamonitorinfo.html

    **Detailed Description**

    The purpose of area monitoring is to inform a user when he/she comes close
    to an area of interest. In general such an area is described by a
    **QGeoCircle** . The circle's center represents the place of interest and
    the area around it identifies the geographical region within which
    notifications are sent.

    A QGeoAreaMonitorInfo object is valid if it has a non-empty name and a valid
    **area** (). Such objects must be registered with a
    **QGeoAreaMonitorSource**  to start and stop the monitoring process. Note
    that extensive monitoring can be very resource consuming because the
    positioning engine must remain active and has to match the current position
    with each QGeoAreaMonitorInfo instance.

    To further reduce the burden on the system there are optional attributes
    which can set. Each monitored area can have an expiry date which
    automatically removes the to-be-monitored area from the monitoring source
    once the expiry date has been reached. Another option is to adjust the
    persistence of a monitored area. A QGeoAreaMonitorInfo that **isPersistent**
    () will remain active beyond the current applications lifetime. If an area
    is entered while the monitoring application is not running the application
    will be started. Note that this feature is not available on all platforms.
    Its availability can be checked via
    **QGeoAreaMonitorSource::supportedAreaMonitorFeatures** ().

    **See also** **QGeoAreaMonitorSource** .
    """

    @typing.overload
    def __init__(self, name: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#QGeoAreaMonitorInfo

        **QGeoAreaMonitorInfo::QGeoAreaMonitorInfo(const QString & name =
        QString())**

        Constructs a QGeoAreaMonitorInfo object with the specified **name**.

        **See also** **name** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoAreaMonitorInfo") -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#QGeoAreaMonitorInfo-1

        **QGeoAreaMonitorInfo::QGeoAreaMonitorInfo(const QGeoAreaMonitorInfo &
        other )**

        Constructs a QGeoAreaMonitorInfo object as a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def swap(self, other: "QGeoAreaMonitorInfo") -> None:
        ...

    def setNotificationParameters(
        self, parameters: typing.Dict[str, typing.Any]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#setNotificationParameter
        s

        **void QGeoAreaMonitorInfo::setNotificationParameters(const QVariantMap
        & parameters )**

        Sets the set of platform specific **parameters** used by
        **QGeoAreaMonitorInfo** .

        **See also** **notificationParameters** ().
        """
        ...

    def notificationParameters(self) -> typing.Dict[str, typing.Any]:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#notificationParameters

        **QVariantMap QGeoAreaMonitorInfo::notificationParameters() const**

        Returns the set of platform specific parameters used by this
        **QGeoAreaMonitorInfo** .

        **See also** **setNotificationParameters** ().
        """
        ...

    def setPersistent(self, isPersistent: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#setPersistent

        **void QGeoAreaMonitorInfo::setPersistent(bool isPersistent )**

        Sets the **QGeoAreaMonitorInfo**  object's persistence to
        **isPersistent**.

        Note that setting this flag does not imply that
        **QGeoAreaMonitorSource**  supports persistent monitoring.
        **QGeoAreaMonitorSource::supportedAreaMonitorFeatures** () can be used
        to check for this feature's availability.

        **See also** **isPersistent** ().
        """
        ...

    def isPersistent(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#isPersistent

        **bool QGeoAreaMonitorInfo::isPersistent() const**

        Returns true if the **QGeoAreaMonitorInfo**  is persistent. The default
        value for this property is false.

        A non-persistent **QGeoAreaMonitorInfo**  will be removed by the system
        once the application owning the monitor object stops. Persistent objects
        remain active and can be retrieved once the application restarts.

        If the system triggers an event associated to a persistent
        **QGeoAreaMonitorInfo**  the relevant application will be re-started and
        the appropriate signal emitted.

        **See also** **setPersistent** ().
        """
        ...

    def setExpiration(
        self, expiry: typing.Union[QtCore.QDateTime, datetime.datetime]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#setExpiration

        **void QGeoAreaMonitorInfo::setExpiration(const QDateTime & expiry )**

        Sets the expiry date and time to **expiry**.

        **See also** **expiration** ().
        """
        ...

    def expiration(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#expiration

        **QDateTime QGeoAreaMonitorInfo::expiration() const**

        Returns the expiry date.

        After an active **QGeoAreaMonitorInfo**  has expired the region is no
        longer monitored and the **QGeoAreaMonitorInfo**  object is removed from
        the list of **active monitors** .

        If the expiry **QDateTime**  is invalid the **QGeoAreaMonitorInfo**
        object is treated as not having an expiry date. This implies an
        indefinite monitoring period if the object is persistent or until the
        current application closes if the object is non-persistent.

        **See also** **setExpiration** () and
        **QGeoAreaMonitorSource::activeMonitors** ().
        """
        ...

    def setArea(self, newShape: "QGeoShape") -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#setArea

        **void QGeoAreaMonitorInfo::setArea(const QGeoShape & newShape )**

        Sets the to-be-monitored area to **newShape**.

        **See also** **area** ().
        """
        ...

    def area(self) -> "QGeoShape":
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#area

        **QGeoShape QGeoAreaMonitorInfo::area() const**

        Returns the boundaries of the to-be-monitored area. This area must not
        be empty.

        **See also** **setArea** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#isValid

        **bool QGeoAreaMonitorInfo::isValid() const**

        Returns true, if the monitor is valid. A valid **QGeoAreaMonitorInfo**
        has a non-empty **name** () and the monitored area is not **empty** ().
        Otherwise this function returns false.
        """
        ...

    def identifier(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#identifier

        **QString QGeoAreaMonitorInfo::identifier() const**

        Returns the identifier of the **QGeoAreaMonitorInfo**  object. The
        identifier is automatically generated upon construction of a new
        **QGeoAreaMonitorInfo**  object.
        """
        ...

    def setName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#setName

        **void QGeoAreaMonitorInfo::setName(const QString & name )**

        Sets the user visibile **name**.

        **See also** **name** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoareamonitorinfo.html#name

        **QString QGeoAreaMonitorInfo::name() const**

        Returns the name of the **QGeoAreaMonitorInfo**  object. The name should
        be used for user-visibility purposes.

        **See also** **setName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtQml import *
import enum


class QJSPrimitiveValue(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsprimitivevalue.html

    **Detailed Description**

    QJSPrimitiveValue supports most of the primitive types defined in the
    **ECMA-262**  standard, in particular Undefined, Boolean, Number, and
    String. Additionally, you can store a JavaScript null in a QJSPrimitiveValue
    and as a special case of Number, you can store an integer value.

    All those values are stored immediately, without interacting with the
    JavaScript heap. Therefore, you can pass QJSPrimitiveValues between
    different JavaScript engines. In contrast to **QJSManagedValue** , there is
    also no danger in destroying a QJSPrimitiveValue from a different thread
    than it was created in. On the flip side, QJSPrimitiveValue does not hold a
    reference to any JavaScript engine.

    QJSPrimitiveValue implements the JavaScript arithmetic and comparison
    operators on the supported types in JavaScript semantics. Types are coerced
    like the JavaScript engine would coerce them if the operators were written
    in a JavaScript expression.

    The JavaScript Symbol type is not supported as it is of very limited utility
    regarding arithmetic and comparison operators, the main purpose of
    QJSPrimitiveValue. In particular, it causes an exception whenever you try to
    coerce it to a number or a string, and we cannot throw exceptions without a
    JavaScript Engine.
    """

    class Type(enum.Enum):
        Undefined: QJSPrimitiveValue = ...
        Null: QJSPrimitiveValue = ...
        Boolean: QJSPrimitiveValue = ...
        Integer: QJSPrimitiveValue = ...
        Double: QJSPrimitiveValue = ...
        String: QJSPrimitiveValue = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue

        **QJSPrimitiveValue::QJSPrimitiveValue()**

        Creates a QJSPrimitiveValue of type Undefined.
        """
        ...

    @typing.overload
    def __init__(self, undefined: QJSPrimitiveUndefined) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-1

        **QJSPrimitiveValue::QJSPrimitiveValue(QJSPrimitiveUndefined undefined
        )**

        Creates a QJSPrimitiveValue of value **undefined** and type Undefined.
        """
        ...

    @typing.overload
    def __init__(self, null: QJSPrimitiveNull) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-2

        **QJSPrimitiveValue::QJSPrimitiveValue(QJSPrimitiveNull null )**

        Creates a QJSPrimitiveValue of value **null** and type Null.
        """
        ...

    @typing.overload
    def __init__(self, value: bool) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-3

        **QJSPrimitiveValue::QJSPrimitiveValue(bool value )**

        Creates a QJSPrimitiveValue of value **value** and type Boolean.
        """
        ...

    @typing.overload
    def __init__(self, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-4

        **QJSPrimitiveValue::QJSPrimitiveValue(int value )**

        Creates a QJSPrimitiveValue of value **value** and type Integer.
        """
        ...

    @typing.overload
    def __init__(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-5

        **QJSPrimitiveValue::QJSPrimitiveValue(double value )**

        Creates a QJSPrimitiveValue of value **value** and type Double.
        """
        ...

    @typing.overload
    def __init__(self, string: str) -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue-6

        **QJSPrimitiveValue::QJSPrimitiveValue(QString value )**

        Creates a QJSPrimitiveValue of value **value** and type String.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QJSPrimitiveValue") -> None:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#QJSPrimitiveValue

        **QJSPrimitiveValue::QJSPrimitiveValue()**

        Creates a QJSPrimitiveValue of type Undefined.
        """
        ...

    def __neg__(self) -> "QJSPrimitiveValue":
        ...

    def __pos__(self) -> "QJSPrimitiveValue":
        ...

    def equals(self, other: "QJSPrimitiveValue") -> bool:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#equals

        **bool QJSPrimitiveValue::equals(const QJSPrimitiveValue & other )
        const**

        Performs the JavaScript '==' operation on this **QJSPrimitiveValue**
        and **other** , and returns the result.
        """
        ...

    def strictlyEquals(self, other: "QJSPrimitiveValue") -> bool:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#strictlyEquals

        **bool QJSPrimitiveValue::strictlyEquals(const QJSPrimitiveValue & other
        ) const**

        Performs the JavaScript '===' operation on this **QJSPrimitiveValue**
        and **other** , and returns the result.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#toString

        **QString QJSPrimitiveValue::toString() const**

        Returns the value coerced to a JavaScript String by JavaScript rules.
        """
        ...

    def toDouble(self) -> float:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#toDouble

        **double QJSPrimitiveValue::toDouble() const**

        Returns the value coerced to a JavaScript Number by JavaScript rules.
        """
        ...

    def toInteger(self) -> int:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#toInteger

        **int QJSPrimitiveValue::toInteger() const**

        Returns the value coerced to an integral 32bit number by the rules
        JavaScript would apply when preparing it for a bit shift operation.
        """
        ...

    def toBoolean(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#toBoolean

        **bool QJSPrimitiveValue::toBoolean() const**

        Returns the value coerced a boolean by JavaScript rules.
        """
        ...

    def type(self) -> "QJSPrimitiveValue.Type":
        """
        https://doc.qt.io/qt-6/qjsprimitivevalue.html#type

        **QJSPrimitiveValue::Type QJSPrimitiveValue::type() const**

        Returns the type of the **QJSPrimitiveValue** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QMouseEvent(QSinglePointEvent):
    """
    https://doc.qt.io/qt-6/qmouseevent.html

    **Detailed Description**

    Mouse events occur when a mouse button is pressed or released inside a
    widget, or when the mouse cursor is moved.

    Mouse move events will occur only when a mouse button is pressed down,
    unless mouse tracking has been enabled with **QWidget::setMouseTracking**
    ().

    Qt automatically grabs the mouse when a mouse button is pressed inside a
    widget; the widget will continue to receive mouse events until the last
    mouse button is released.

    A mouse event contains a special accept flag that indicates whether the
    receiver wants the event. You should call **ignore** () if the mouse event
    is not handled by your widget. A mouse event is propagated up the parent
    widget chain until a widget accepts it with **accept** (), or an event
    filter consumes it.

    **Note:** If a mouse event is propagated to a **widget**  for which
    **Qt::WA_NoMousePropagation**  has been set, that mouse event will not be
    propagated further up the parent widget chain.

    The state of the keyboard modifier keys can be found by calling the
    **modifiers** () function, inherited from **QInputEvent** .

    The **position** () function gives the cursor position relative to the
    widget or item that receives the mouse event. If you move the widget as a
    result of the mouse event, use the global position returned by
    **globalPosition** () to avoid a shaking motion.

    The **QWidget::setEnabled** () function can be used to enable or disable
    mouse and keyboard events for a widget.

    Reimplement the **QWidget**  event handlers, **QWidget::mousePressEvent**
    (), **QWidget::mouseReleaseEvent** (), **QWidget::mouseDoubleClickEvent**
    (), and **QWidget::mouseMoveEvent** () to receive mouse events in your own
    widgets.

    **See also** **QWidget::setMouseTracking** (), **QWidget::grabMouse** (),
    and **QCursor::pos** ().
    """

    @typing.overload
    def __init__(
        self,
        type: QtCore.QEvent.Type,
        localPos: QtCore.QPointF,
        button: QtCore.Qt.MouseButton,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
        device: typing.Optional["QPointingDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmouseevent.html#QMouseEvent-2

        **QMouseEvent::QMouseEvent(QEvent::Type type , const QPointF & localPos
        , Qt::MouseButton button , Qt::MouseButtons buttons ,
        Qt::KeyboardModifiers modifiers , const QPointingDevice * device =
        QPointingDevice::primaryPointingDevice())**

        Constructs a mouse event object originating from **device**.

        The **type** parameter must be one of **QEvent::MouseButtonPress** ,
        **QEvent::MouseButtonRelease** , **QEvent::MouseButtonDblClick** , or
        **QEvent::MouseMove** .

        The **localPos** is the mouse cursor's position relative to the
        receiving widget or item. The window position is set to the same value
        as **localPos**. The **button** that caused the event is given as a
        value from the **Qt::MouseButton**  enum. If the event **type** is
        **MouseMove** , the appropriate button for this event is
        **Qt::NoButton** . The mouse and keyboard states at the time of the
        event are specified by **buttons** and **modifiers**.

        The **globalPosition** () is initialized to **QCursor::pos** (), which
        may not be appropriate. Use the other constructor to specify the global
        position explicitly.
        """
        ...

    @typing.overload
    def __init__(
        self,
        type: QtCore.QEvent.Type,
        localPos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        button: QtCore.Qt.MouseButton,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
        device: typing.Optional["QPointingDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmouseevent.html#QMouseEvent-3

        **QMouseEvent::QMouseEvent(QEvent::Type type , const QPointF & localPos
        , const QPointF & globalPos , Qt::MouseButton button , Qt::MouseButtons
        buttons , Qt::KeyboardModifiers modifiers , const QPointingDevice *
        device = QPointingDevice::primaryPointingDevice())**

        Constructs a mouse event object originating from **device**.

        The **type** parameter must be **QEvent::MouseButtonPress** ,
        **QEvent::MouseButtonRelease** , **QEvent::MouseButtonDblClick** , or
        **QEvent::MouseMove** .

        The **localPos** is the mouse cursor's position relative to the
        receiving widget or item. The cursor's position in screen coordinates is
        specified by **globalPos**. The window position is set to the same value
        as **localPos**. The **button** that caused the event is given as a
        value from the **Qt::MouseButton**  enum. If the event **type** is
        **MouseMove** , the appropriate button for this event is
        **Qt::NoButton** . **buttons** is the state of all buttons at the time
        of the event, **modifiers** the state of all keyboard modifiers.
        """
        ...

    @typing.overload
    def __init__(
        self,
        type: QtCore.QEvent.Type,
        localPos: QtCore.QPointF,
        scenePos: QtCore.QPointF,
        globalPos: QtCore.QPointF,
        button: QtCore.Qt.MouseButton,
        buttons: QtCore.Qt.MouseButton,
        modifiers: QtCore.Qt.KeyboardModifier,
        device: typing.Optional["QPointingDevice"] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qmouseevent.html#QMouseEvent-4

        **QMouseEvent::QMouseEvent(QEvent::Type type , const QPointF & localPos
        , const QPointF & scenePos , const QPointF & globalPos , Qt::MouseButton
        button , Qt::MouseButtons buttons , Qt::KeyboardModifiers modifiers ,
        const QPointingDevice * device =
        QPointingDevice::primaryPointingDevice())**

        Constructs a mouse event object.

        The **type** parameter must be **QEvent::MouseButtonPress** ,
        **QEvent::MouseButtonRelease** , **QEvent::MouseButtonDblClick** , or
        **QEvent::MouseMove** .

        The points **localPos** , **scenePos** and **globalPos** specify the
        mouse cursor's position relative to the receiving widget or item,
        window, and screen or desktop, respectively.

        The **button** that caused the event is given as a value from the
        **Qt::MouseButton**  enum. If the event **type** is **MouseMove** , the
        appropriate button for this event is **Qt::NoButton** . **buttons** is
        the state of all buttons at the time of the event, **modifiers** is the
        state of all keyboard modifiers.
        """
        ...

    def clone(self) -> "QMouseEvent":
        ...

    def flags(self) -> QtCore.Qt.MouseEventFlag:
        """
        https://doc.qt.io/qt-6/qmouseevent.html#flags

        **[since 5.3] Qt::MouseEventFlags QMouseEvent::flags() const**

        Returns the mouse event flags.

        The mouse event flags provide additional information about a mouse
        event.

        This function was introduced in Qt 5.3.

        **See also** **Qt::MouseEventFlag**  and
        **QGraphicsSceneMouseEvent::flags** ().
        """
        ...

    def pos(self) -> QtCore.QPoint:
        """
        https://doc.qt.io/qt-6/qmouseevent.html#pos

        **QPoint QMouseEvent::pos() const**

        Returns the position of the mouse cursor, relative to the widget that
        received the event.

        If you move the widget as a result of the mouse event, use the global
        position returned by globalPos() to avoid a shaking motion.

        **See also** **x** (), **y** (), and **globalPos** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtDBus import *
import enum


class QDBusError(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdbuserror.html

    **Detailed Description**

    When dealing with the D-Bus bus service or with remote applications over
    D-Bus, a number of error conditions can happen. This error conditions are
    sometimes signalled by a returned error value or by a QDBusError.

    C++ and Java exceptions are a valid analogy for D-Bus errors: instead of
    returning normally with a return value, remote applications and the bus may
    decide to throw an error condition. However, the Qt D-Bus implementation
    does not use the C++ exception-throwing mechanism, so you will receive
    QDBusErrors in the return reply (see **QDBusReply::error** ()).

    QDBusError objects are used to inspect the error name and message as
    received from the bus and remote applications. You should not create such
    objects yourself to signal error conditions when called from D-Bus: instead,
    use **QDBusMessage::createError** () and **QDBusConnection::send** ().

    **See also** **QDBusConnection::send** (), **QDBusMessage** , and
    **QDBusReply** .
    """

    class ErrorType(enum.Enum):
        NoError: QDBusError = ...
        Other: QDBusError = ...
        Failed: QDBusError = ...
        NoMemory: QDBusError = ...
        ServiceUnknown: QDBusError = ...
        NoReply: QDBusError = ...
        BadAddress: QDBusError = ...
        NotSupported: QDBusError = ...
        LimitsExceeded: QDBusError = ...
        AccessDenied: QDBusError = ...
        NoServer: QDBusError = ...
        Timeout: QDBusError = ...
        NoNetwork: QDBusError = ...
        AddressInUse: QDBusError = ...
        Disconnected: QDBusError = ...
        InvalidArgs: QDBusError = ...
        UnknownMethod: QDBusError = ...
        TimedOut: QDBusError = ...
        InvalidSignature: QDBusError = ...
        UnknownInterface: QDBusError = ...
        InternalError: QDBusError = ...
        UnknownObject: QDBusError = ...
        InvalidService: QDBusError = ...
        InvalidObjectPath: QDBusError = ...
        InvalidInterface: QDBusError = ...
        InvalidMember: QDBusError = ...
        UnknownProperty: QDBusError = ...
        PropertyReadOnly: QDBusError = ...

    def __init__(self, other: "QDBusError") -> None:
        ...

    def swap(self, other: "QDBusError") -> None:
        """
        https://doc.qt.io/qt-6/qdbuserror.html#swap

        **void QDBusError::swap(QDBusError & other )**

        Swaps this **QDBusError**  instance with **other**.
        """
        ...

    @staticmethod
    def errorString(error: "QDBusError.ErrorType") -> str:
        """
        https://doc.qt.io/qt-6/qdbuserror.html#errorString

        **[static] QString QDBusError::errorString(QDBusError::ErrorType error
        )**

        Returns the error name associated with error condition **error**.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbuserror.html#isValid

        **bool QDBusError::isValid() const**

        Returns `true` if this is a valid error condition (i.e., if there was an
        error), otherwise false.
        """
        ...

    def message(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbuserror.html#message

        **QString QDBusError::message() const**

        Returns the message that the callee associated with this error. Error
        messages are implementation defined and usually contain a human-readable
        error code, though this does not mean it is suitable for your end-users.
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbuserror.html#name

        **QString QDBusError::name() const**

        Returns this error's name. Error names are similar to D-Bus Interface
        names, like `org.freedesktop.DBus.InvalidArgs`.

        **See also** **type** ().
        """
        ...

    def type(self) -> "QDBusError.ErrorType":
        """
        https://doc.qt.io/qt-6/qdbuserror.html#type

        **QDBusError::ErrorType QDBusError::type() const**

        Returns this error's **ErrorType** .

        **See also** **ErrorType** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QXmlStreamWriter(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qxmlstreamwriter.html

    **Detailed Description**

    QXmlStreamWriter is the counterpart to **QXmlStreamReader**  for writing
    XML. Like its related class, it operates on a **QIODevice**  specified with
    **setDevice** (). The API is simple and straightforward: for every XML token
    or event you want to write, the writer provides a specialized function.

    You start a document with **writeStartDocument** () and end it with
    **writeEndDocument** (). This will implicitly close all remaining open tags.

    Element tags are opened with **writeStartElement** () followed by
    **writeAttribute** () or **writeAttributes** (), element content, and then
    **writeEndElement** (). A shorter form **writeEmptyElement** () can be used
    to write empty elements, followed by **writeAttributes** ().

    Element content consists of either characters, entity references or nested
    elements. It is written with **writeCharacters** (), which also takes care
    of escaping all forbidden characters and character sequences,
    **writeEntityReference** (), or subsequent calls to **writeStartElement**
    (). A convenience method **writeTextElement** () can be used for writing
    terminal elements that contain nothing but text.

    The following abridged code snippet shows the basic use of the class to
    write formatted XML with indentation:

    **QXmlStreamWriter**  stream(&output);
    stream.setAutoFormatting(true);
            stream.writeStartDocument();
    ...
            stream.writeStartElement("bookmark");
    stream.writeAttribute("href", "http://qt-project.org/");
    stream.writeTextElement("title", "Qt Project");
    stream.writeEndElement(); // bookmark
            ...
    stream.writeEndDocument();

    QXmlStreamWriter takes care of prefixing namespaces, all you have to do is
    specify the `namespaceUri` when writing elements or attributes. If you must
    conform to certain prefixes, you can force the writer to use them by
    declaring the namespaces manually with either **writeNamespace** () or
    **writeDefaultNamespace** (). Alternatively, you can bypass the stream
    writer's namespace support and use overloaded methods that take a qualified
    name instead. The namespace **http://www.w3.org/XML/1998/namespace** is
    implicit and mapped to the prefix **xml**.

    The stream writer can automatically format the generated XML data by adding
    line-breaks and indentation to empty sections between elements, making the
    XML data more readable for humans and easier to work with for most source
    code management systems. The feature can be turned on with the
    **autoFormatting**  property, and customized with the
    **autoFormattingIndent**  property.

    Other functions are **writeCDATA** (), **writeComment** (),
    **writeProcessingInstruction** (), and **writeDTD** (). Chaining of XML
    streams is supported with **writeCurrentToken** ().

    QXmlStreamWriter always encodes XML in UTF-8.

    If an error occurs while writing to the underlying device, **hasError** ()
    starts returning true and subsequent writes are ignored.

    The **QXmlStream Bookmarks Example**  illustrates how to use a stream writer
    to write an XML bookmark file (XBEL) that was previously read in by a
    **QXmlStreamReader** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#QXmlStreamWriter

        **QXmlStreamWriter::QXmlStreamWriter()**

        Constructs a stream writer.

        **See also** **setDevice** ().
        """
        ...

    @typing.overload
    def __init__(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#QXmlStreamWriter-1

        **QXmlStreamWriter::QXmlStreamWriter(QIODevice * device )**

        Constructs a stream writer that writes into **device** ;
        """
        ...

    @typing.overload
    def __init__(self, array: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#QXmlStreamWriter-2

        **QXmlStreamWriter::QXmlStreamWriter(QByteArray * array )**

        Constructs a stream writer that writes into **array**. This is the same
        as creating an xml writer that operates on a **QBuffer**  device which
        in turn operates on **array**.
        """
        ...

    def hasError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#hasError

        **bool QXmlStreamWriter::hasError() const**

        Returns `true` if writing failed.

        This can happen if the stream failed to write to the underlying device
        or if the data to be written contained invalid characters.

        The error status is never reset. Writes happening after the error
        occurred may be ignored, even if the error condition is cleared.
        """
        ...

    def writeCurrentToken(self, reader: QXmlStreamReader) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeCurrentToken

        **void QXmlStreamWriter::writeCurrentToken(const QXmlStreamReader &
        reader )**

        Writes the current state of the **reader**. All possible valid states
        are supported.

        The purpose of this function is to support chained processing of XML
        data.

        **See also** **QXmlStreamReader::tokenType** ().
        """
        ...

    @typing.overload
    def writeStartElement(self, qualifiedName: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeStartElement

        **void QXmlStreamWriter::writeStartElement(const QString & namespaceUri
        , const QString & name )**

        Writes a start element with **name** , prefixed for the specified
        **namespaceUri**. If the namespace has not been declared yet,
        **QXmlStreamWriter**  will generate a namespace declaration for it.
        Subsequent calls to **writeAttribute** () will add attributes to this
        element.

        **See also** **writeNamespace** (), **writeEndElement** (), and
        **writeEmptyElement** ().
        """
        ...

    @typing.overload
    def writeStartElement(self, namespaceUri: str, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeStartElement-1

        **void QXmlStreamWriter::writeStartElement(const QString & qualifiedName
        )**

        This is an overloaded function.

        Writes a start element with **qualifiedName**. Subsequent calls to
        **writeAttribute** () will add attributes to this element.

        **See also** **writeEndElement** () and **writeEmptyElement** ().
        """
        ...

    @typing.overload
    def writeStartDocument(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeStartDocument

        **void QXmlStreamWriter::writeStartDocument(const QString & version )**

        Writes a document start with the XML version number **version**.

        **See also** **writeEndDocument** ().
        """
        ...

    @typing.overload
    def writeStartDocument(self, version: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeStartDocument-1

        **void QXmlStreamWriter::writeStartDocument()**

        This is an overloaded function.

        Writes a document start with XML version number "1.0".

        **See also** **writeEndDocument** ().
        """
        ...

    @typing.overload
    def writeStartDocument(self, version: str, standalone: bool) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeStartDocument-2

        **void QXmlStreamWriter::writeStartDocument(const QString & version ,
        bool standalone )**

        Writes a document start with the XML version number **version** and a
        standalone attribute **standalone**.

        **See also** **writeEndDocument** ().
        """
        ...

    def writeProcessingInstruction(self, target: str, data: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeProcessingInstruction

        **void QXmlStreamWriter::writeProcessingInstruction(const QString &
        target , const QString & data = QString())**

        Writes an XML processing instruction with **target** and **data** ,
        where **data** must not contain the sequence "?>".
        """
        ...

    def writeDefaultNamespace(self, namespaceUri: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeDefaultNamespace

        **void QXmlStreamWriter::writeDefaultNamespace(const QString &
        namespaceUri )**

        Writes a default namespace declaration for **namespaceUri**.

        If **writeStartElement** () or **writeEmptyElement** () was called, the
        declaration applies to the current element; otherwise it applies to the
        next child element.

        Note that the namespaces **http://www.w3.org/XML/1998/namespace** (bound
        to **xmlns** ) and **http://www.w3.org/2000/xmlns/** (bound to **xml** )
        by definition cannot be declared as default.
        """
        ...

    def writeNamespace(self, namespaceUri: str, prefix: str = ...) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeNamespace

        **void QXmlStreamWriter::writeNamespace(const QString & namespaceUri ,
        const QString & prefix = QString())**

        Writes a namespace declaration for **namespaceUri** with **prefix**. If
        **prefix** is empty, **QXmlStreamWriter**  assigns a unique prefix
        consisting of the letter 'n' followed by a number.

        If **writeStartElement** () or **writeEmptyElement** () was called, the
        declaration applies to the current element; otherwise it applies to the
        next child element.

        Note that the prefix **xml** is both predefined and reserved for
        **http://www.w3.org/XML/1998/namespace** , which in turn cannot be bound
        to any other prefix. The prefix **xmlns** and its URI
        **http://www.w3.org/2000/xmlns/** are used for the namespace mechanism
        itself and thus completely forbidden in declarations.
        """
        ...

    def writeEntityReference(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeEntityReference

        **void QXmlStreamWriter::writeEntityReference(const QString & name )**

        Writes the entity reference **name** to the stream, as "& **name** ;".
        """
        ...

    def writeEndElement(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeEndElement

        **void QXmlStreamWriter::writeEndElement()**

        Closes the previous start element.

        **See also** **writeStartElement** ().
        """
        ...

    def writeEndDocument(self) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeEndDocument

        **void QXmlStreamWriter::writeEndDocument()**

        Closes all remaining open start elements and writes a newline.

        **See also** **writeStartDocument** ().
        """
        ...

    @typing.overload
    def writeTextElement(self, qualifiedName: str, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeTextElement

        **void QXmlStreamWriter::writeTextElement(const QString & namespaceUri ,
        const QString & name , const QString & text )**

        Writes a text element with **name** , prefixed for the specified
        **namespaceUri** , and **text**. If the namespace has not been declared,
        **QXmlStreamWriter**  will generate a namespace declaration for it.

        This is a convenience function equivalent to:

        writeStartElement(namespaceUri, name);
        writeCharacters(text);
                    writeEndElement();
        """
        ...

    @typing.overload
    def writeTextElement(self, namespaceUri: str, name: str, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeTextElement-1

        **void QXmlStreamWriter::writeTextElement(const QString & qualifiedName
        , const QString & text )**

        This is an overloaded function.

        Writes a text element with **qualifiedName** and **text**.

        This is a convenience function equivalent to:

        writeStartElement(qualifiedName);
                    writeCharacters(text);
        writeEndElement();
        """
        ...

    @typing.overload
    def writeEmptyElement(self, qualifiedName: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeEmptyElement

        **void QXmlStreamWriter::writeEmptyElement(const QString & namespaceUri
        , const QString & name )**

        Writes an empty element with **name** , prefixed for the specified
        **namespaceUri**. If the namespace has not been declared,
        **QXmlStreamWriter**  will generate a namespace declaration for it.
        Subsequent calls to **writeAttribute** () will add attributes to this
        element.

        **See also** **writeNamespace** ().
        """
        ...

    @typing.overload
    def writeEmptyElement(self, namespaceUri: str, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeEmptyElement-1

        **void QXmlStreamWriter::writeEmptyElement(const QString & qualifiedName
        )**

        This is an overloaded function.

        Writes an empty element with qualified name **qualifiedName**.
        Subsequent calls to **writeAttribute** () will add attributes to this
        element.
        """
        ...

    def writeDTD(self, dtd: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeDTD

        **void QXmlStreamWriter::writeDTD(const QString & dtd )**

        Writes a DTD section. The **dtd** represents the entire doctypedecl
        production from the XML 1.0 specification.
        """
        ...

    def writeComment(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeComment

        **void QXmlStreamWriter::writeComment(const QString & text )**

        Writes **text** as XML comment, where **text** must not contain the
        forbidden sequence "--" or end with "-". Note that XML does not provide
        any way to escape "-" in a comment.
        """
        ...

    def writeCharacters(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeCharacters

        **void QXmlStreamWriter::writeCharacters(const QString & text )**

        Writes **text**. The characters "<", "&", and ""\" are escaped as entity
        references "&lt;", "&amp;, and "&quot;". To avoid the forbidden sequence
        "]]>", ">" is also escaped as "&gt;".

        **See also** **writeEntityReference** ().
        """
        ...

    def writeCDATA(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeCDATA

        **void QXmlStreamWriter::writeCDATA(const QString & text )**

        Writes **text** as CDATA section. If **text** contains the forbidden
        character sequence "]]>", it is split into different CDATA sections.

        This function mainly exists for completeness. Normally you should not
        need use it, because **writeCharacters** () automatically escapes all
        non-content characters.
        """
        ...

    def writeAttributes(self, attributes: "QXmlStreamAttributes") -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeAttributes

        **void QXmlStreamWriter::writeAttributes(const QXmlStreamAttributes &
        attributes )**

        Writes the attribute vector **attributes**. If a namespace referenced in
        an attribute not been declared yet, **QXmlStreamWriter**  will generate
        a namespace declaration for it.

        This function can only be called after **writeStartElement** () before
        any content is written, or after **writeEmptyElement** ().

        **See also** **writeAttribute** () and **writeNamespace** ().
        """
        ...

    @typing.overload
    def writeAttribute(self, qualifiedName: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeAttribute

        **void QXmlStreamWriter::writeAttribute(const QString & namespaceUri ,
        const QString & name , const QString & value )**

        Writes an attribute with **name** and **value** , prefixed for the
        specified **namespaceUri**. If the namespace has not been declared yet,
        **QXmlStreamWriter**  will generate a namespace declaration for it.

        This function can only be called after **writeStartElement** () before
        any content is written, or after **writeEmptyElement** ().
        """
        ...

    @typing.overload
    def writeAttribute(self, namespaceUri: str, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeAttribute-1

        **void QXmlStreamWriter::writeAttribute(const QString & qualifiedName ,
        const QString & value )**

        This is an overloaded function.

        Writes an attribute with **qualifiedName** and **value**.

        This function can only be called after **writeStartElement** () before
        any content is written, or after **writeEmptyElement** ().
        """
        ...

    @typing.overload
    def writeAttribute(self, attribute: QXmlStreamAttribute) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#writeAttribute-2

        **void QXmlStreamWriter::writeAttribute(const QXmlStreamAttribute &
        attribute )**

        This is an overloaded function.

        Writes the **attribute**.

        This function can only be called after **writeStartElement** () before
        any content is written, or after **writeEmptyElement** ().
        """
        ...

    def autoFormattingIndent(self) -> int:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#autoFormattingIndent-prop

        **autoFormattingIndent : int**

        This property holds the number of spaces or tabs used for indentation
        when auto-formatting is enabled. Positive numbers indicate spaces,
        negative numbers tabs.

        The default indentation is 4.

        **Access functions:**

        int **autoFormattingIndent** () const
        void **setAutoFormattingIndent**
        (int **spacesOrTabs** )

        **See also** **autoFormatting** .

        **Member Function Documentation**
        """
        ...

    def setAutoFormattingIndent(self, spaces: int) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#autoFormattingIndent-prop

        **autoFormattingIndent : int**

        This property holds the number of spaces or tabs used for indentation
        when auto-formatting is enabled. Positive numbers indicate spaces,
        negative numbers tabs.

        The default indentation is 4.

        **Access functions:**

        int **autoFormattingIndent** () const
        void **setAutoFormattingIndent**
        (int **spacesOrTabs** )

        **See also** **autoFormatting** .

        **Member Function Documentation**
        """
        ...

    def autoFormatting(self) -> bool:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#autoFormatting

        **bool QXmlStreamWriter::autoFormatting() const**

        Returns `true` if auto formatting is enabled, otherwise `false`.

        **Note:** Getter function for property autoFormatting.

        **See also** **setAutoFormatting** ().
        """
        ...

    def setAutoFormatting(self, a0: bool) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#setAutoFormatting

        **void QXmlStreamWriter::setAutoFormatting(bool enable )**

        Enables auto formatting if **enable** is `true`, otherwise disables it.

        The default value is `false`.

        **Note:** Setter function for property **autoFormatting** .

        **See also** **autoFormatting** ().
        """
        ...

    def device(self) -> QIODevice:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#device

        **QIODevice *QXmlStreamWriter::device() const**

        Returns the current device associated with the **QXmlStreamWriter** , or
        `nullptr` if no device has been assigned.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qxmlstreamwriter.html#setDevice

        **void QXmlStreamWriter::setDevice(QIODevice * device )**

        Sets the current device to **device**. If you want the stream to write
        into a **QByteArray** , you can create a **QBuffer**  device.

        **See also** **device** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtDBus import *


class QDBusAbstractInterface(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdbusabstractinterface.html

    **Detailed Description**

    Generated-code classes also derive from QDBusAbstractInterface, all methods
    described here are also valid for generated-code classes. In addition to
    those described here, generated-code classes provide member functions for
    the remote methods, which allow for compile-time checking of the correct
    parameters and return values, as well as property type-matching and signal
    parameter-matching.

    **See also** **The QDBus compiler**  and **QDBusInterface** .
    """

    def __init__(
        self,
        service: str,
        path: str,
        interface: str,
        connection: "QDBusConnection",
        parent: QtCore.QObject,
    ) -> None:
        ...

    def disconnectNotify(self, signal: QtCore.QMetaMethod) -> None:
        ...

    def connectNotify(self, signal: QtCore.QMetaMethod) -> None:
        ...

    def asyncCallWithArgumentList(
        self, method: str, args: typing.Iterable[typing.Any]
    ) -> "QDBusPendingCall":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#asyncCallWithArgument
        List

        **QDBusPendingCall
        QDBusAbstractInterface::asyncCallWithArgumentList(const QString & method
        , const QList<QVariant> & args )**

        Places a call to the remote method specified by **method** on this
        interface, using **args** as arguments. This function returns a
        **QDBusPendingCall**  object that can be used to track the status of the
        reply and access its contents once it has arrived.

        Normally, you should place calls using **asyncCall** ().

        **Note:** This function is **thread-safe** .
        """
        ...

    def asyncCall(self, method: str, *a1) -> "QDBusPendingCall":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#asyncCall-1

        **template <typename Args> QDBusPendingCall
        QDBusAbstractInterface::asyncCall(const QString & method , Args &&...
        args )**

        Calls the method **method** on this interface and passes **args** to the
        method. All **args** must be convertible to **QVariant** .

        The parameters to `call` are passed on to the remote function via D-Bus
        as input arguments. The returned **QDBusPendingCall**  object can be
        used to find out information about the reply.

        It can be used the following way:

        **QString**  value = retrieveValue();
            **QDBusPendingCall**  pcall =
        interface->asyncCall(QLatin1String("Process"), value);
        **QDBusPendingCallWatcher**  *watcher = new **QDBusPendingCallWatcher**
        (pcall);

            **QObject** ::connect(watcher,
        SIGNAL(finished(**QDBusPendingCallWatcher** *)),
        this, SLOT(callFinishedSlot(**QDBusPendingCallWatcher** *)));

        This example illustrates function calling with 0, 1 and 2 parameters and
        illustrates different parameter types passed in each (the first call to
        `"ProcessWorkUnicode"` will contain one Unicode string, the second call
        to `"ProcessWork"` will contain one string and one byte array).

        **Note:** Before Qt 5.14, this function accepted a maximum of just eight
        (8) arguments.

        **See also** **asyncCallWithArgumentList** ().
        """
        ...

    @typing.overload
    def callWithCallback(
        self,
        method: str,
        args: typing.Iterable[typing.Any],
        returnMethod: PYQT_SLOT,
        errorMethod: PYQT_SLOT,
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#callWithCallback

        **bool QDBusAbstractInterface::callWithCallback(const QString & method ,
        const QList<QVariant> & args , QObject * receiver , const char *
        returnMethod , const char * errorMethod )**

        Places a call to the remote method specified by **method** on this
        interface, using **args** as arguments. This function returns
        immediately after queueing the call. The reply from the remote function
        is delivered to the **returnMethod** on object **receiver**. If an error
        occurs, the **errorMethod** on object **receiver** is called instead.

        This function returns `true` if the queueing succeeds. It does not
        indicate that the executed call succeeded. If it fails, the
        **errorMethod** is called. If the queueing failed, this function returns
        `false` and no slot will be called.

        The **returnMethod** must have as its parameters the types returned by
        the function call. Optionally, it may have a **QDBusMessage**  parameter
        as its last or only parameter. The **errorMethod** must have a
        **QDBusError**  as its only parameter.

        **See also** **QDBusError**  and **QDBusMessage** .
        """
        ...

    @typing.overload
    def callWithCallback(
        self, method: str, args: typing.Iterable[typing.Any], slot: PYQT_SLOT
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#callWithCallback-1

        **bool QDBusAbstractInterface::callWithCallback(const QString & method ,
        const QList<QVariant> & args , QObject * receiver , const char * slot
        )**

        This is an overloaded function.

        This function is deprecated. Please use the overloaded version.

        Places a call to the remote method specified by **method** on this
        interface, using **args** as arguments. This function returns
        immediately after queueing the call. The reply from the remote function
        or any errors emitted by it are delivered to the **slot** slot on object
        **receiver**.

        This function returns `true` if the queueing succeeded: it does not
        indicate that the call succeeded. If it failed, the slot will be called
        with an error message. **lastError** () will not be set under those
        circumstances.

        **See also** **QDBusError**  and **QDBusMessage** .
        """
        ...

    def callWithArgumentList(
        self, mode: "QDBus.CallMode", method: str, args: typing.Iterable[typing.Any]
    ) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#callWithArgumentList

        **QDBusMessage
        QDBusAbstractInterface::callWithArgumentList(QDBus::CallMode mode ,
        const QString & method , const QList<QVariant> & args )**

        Places a call to the remote method specified by **method** on this
        interface, using **args** as arguments. This function returns the
        message that was received as a reply, which can be a normal
        **QDBusMessage::ReplyMessage**  (indicating success) or
        **QDBusMessage::ErrorMessage**  (if the call failed). The **mode**
        parameter specifies how this call should be placed.

        If the call succeeds, **lastError** () will be cleared; otherwise, it
        will contain the error this call produced.

        Normally, you should place calls using **call** ().

        **Warning:** If you use `UseEventLoop`, your code must be prepared to
        deal with any reentrancy: other method calls and signals may be
        delivered before this function returns, as well as other Qt queued
        signals and events.

        **Note:** This function is **thread-safe** .
        """
        ...

    @typing.overload
    def call(self, method: str, *a1) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#call-1

        **template <typename Args> QDBusMessage
        QDBusAbstractInterface::call(const QString & method , Args &&... args
        )**

        Calls the method **method** on this interface and passes **args** to the
        method. All **args** must be convertible to **QVariant** .

        The parameters to `call` are passed on to the remote function via D-Bus
        as input arguments. Output arguments are returned in the
        **QDBusMessage**  reply. If the reply is an error reply, **lastError**
        () will also be set to the contents of the error message.

        It can be used the following way:

        **QString**  value = retrieveValue();
            **QDBusMessage**  reply;
        **QDBusReply** <int> api =
        interface->call(QLatin1String("GetAPIVersion"));
            if (api >= 14)
        reply = interface->call(QLatin1String("ProcessWorkUnicode"), value);
        else
              reply = interface->call(QLatin1String("ProcessWork"),
        QLatin1String("UTF-8"), value.toUtf8());

        This example illustrates function calling with 0, 1 and 2 parameters and
        illustrates different parameter types passed in each (the first call to
        `"ProcessWorkUnicode"` will contain one Unicode string, the second call
        to `"ProcessWork"` will contain one string and one byte array).

        **Note:** Before Qt 5.14, this function accepted a maximum of just eight
        (8) arguments.

        **See also** **callWithArgumentList** ().
        """
        ...

    @typing.overload
    def call(self, mode: "QDBus.CallMode", method: str, *a2) -> "QDBusMessage":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#call-3

        **template <typename Args> QDBusMessage
        QDBusAbstractInterface::call(QDBus::CallMode mode , const QString &
        method , Args &&... args )**

        This is an overloaded function.

        Calls the method **method** on this interface and passes **args** to the
        method. All **args** must be convertible to **QVariant** .

        If **mode** is `NoWaitForReply`, then this function will return
        immediately after placing the call, without waiting for a reply from the
        remote method. Otherwise, **mode** indicates whether this function
        should activate the Qt Event Loop while waiting for the reply to arrive.

        If this function reenters the Qt event loop in order to wait for the
        reply, it will exclude user input. During the wait, it may deliver
        signals and other method calls to your application. Therefore, it must
        be prepared to handle a reentrancy whenever a call is placed with
        call().

        **Note:** Before Qt 5.14, this function accepted a maximum of just eight
        (8) arguments.

        **See also** **callWithArgumentList** ().
        """
        ...

    def timeout(self) -> int:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#timeout

        **int QDBusAbstractInterface::timeout() const**

        Returns the current value of the timeout in milliseconds. -1 means the
        default DBus timeout (usually 25 seconds).

        **See also** **setTimeout** ().
        """
        ...

    def setTimeout(self, timeout: int) -> None:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#setTimeout

        **void QDBusAbstractInterface::setTimeout(int timeout )**

        Sets the timeout in milliseconds for all future DBus calls to
        **timeout**. -1 means the default DBus timeout (usually 25 seconds).

        **See also** **timeout** ().
        """
        ...

    def lastError(self) -> "QDBusError":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#lastError

        **QDBusError QDBusAbstractInterface::lastError() const**

        Returns the error the last operation produced, or an invalid error if
        the last operation did not produce an error.
        """
        ...

    def interface(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#interface

        **QString QDBusAbstractInterface::interface() const**

        Returns the name of this interface.
        """
        ...

    def path(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#path

        **QString QDBusAbstractInterface::path() const**

        Returns the object path that this interface is associated with.
        """
        ...

    def service(self) -> str:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#service

        **QString QDBusAbstractInterface::service() const**

        Returns the name of the service this interface is associated with.
        """
        ...

    def connection(self) -> "QDBusConnection":
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#connection

        **QDBusConnection QDBusAbstractInterface::connection() const**

        Returns the connection this interface is associated with.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdbusabstractinterface.html#isValid

        **bool QDBusAbstractInterface::isValid() const**

        Returns `true` if this is a valid reference to a remote object. It
        returns `false` if there was an error during the creation of this
        interface (for instance, if the remote application does not exist).

        Note: when dealing with remote objects, it is not always possible to
        determine if it exists when creating a **QDBusInterface** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtBluetooth import *
import enum


class QLowEnergyAdvertisingData(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html

    **Detailed Description**

    This data can include the device name, GATT services offered by the device,
    and so on. The data set via this class will be used when advertising is
    started by calling **QLowEnergyController::startAdvertising** (). Objects of
    this class can represent an Advertising Data packet or a Scan Response
    packet.

    **Note:** The actual data packets sent over the advertising channel cannot
    contain more than 31 bytes. If the variable-length data set via this class
    exceeds that limit, it will be left out of the packet or truncated,
    depending on the type.

    **See also** **QLowEnergyAdvertisingParameters**  and
    **QLowEnergyController::startAdvertising** ().
    """

    class Discoverability(enum.Enum):
        DiscoverabilityNone: QLowEnergyAdvertisingData = ...
        DiscoverabilityLimited: QLowEnergyAdvertisingData = ...
        DiscoverabilityGeneral: QLowEnergyAdvertisingData = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#QLowEnergyAdvertis
        ingData

        **QLowEnergyAdvertisingData::QLowEnergyAdvertisingData()**

        Creates a new object of this class. All values are initialized to their
        defaults according to the Bluetooth Low Energy specification.
        """
        ...

    @typing.overload
    def __init__(self, other: "QLowEnergyAdvertisingData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#QLowEnergyAdvertis
        ingData-1

        **QLowEnergyAdvertisingData::QLowEnergyAdvertisingData(const
        QLowEnergyAdvertisingData & other )**

        Constructs a new object of this class that is a copy of **other**.
        """
        ...

    def swap(self, other: "QLowEnergyAdvertisingData") -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#swap

        **void QLowEnergyAdvertisingData::swap(QLowEnergyAdvertisingData & other
        )**

        Swaps this object with **other**.
        """
        ...

    def rawData(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#rawData

        **QByteArray QLowEnergyAdvertisingData::rawData() const**

        Returns the user-supplied raw data to be advertised. The default is an
        empty byte array.

        **See also** **setRawData** ().
        """
        ...

    def setRawData(self, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setRawData

        **void QLowEnergyAdvertisingData::setRawData(const QByteArray & data )**

        Sets the data to be advertised to **data**. If the value is not an empty
        byte array, it will be sent as-is as the advertising data and all other
        data in this object will be ignored. This can be used to send non-
        standard data.

        **Note:** If **data** is longer than 31 bytes, it will be truncated. It
        is the caller's responsibility to ensure that **data** is well-formed.

        **See also** **rawData** ().
        """
        ...

    def services(self) -> typing.List[QBluetoothUuid]:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#services

        **QList<QBluetoothUuid> QLowEnergyAdvertisingData::services() const**

        Returns the list of service UUIDs to be advertised. By default, this
        list is empty.

        **See also** **setServices** ().
        """
        ...

    def setServices(self, services: typing.Iterable[QBluetoothUuid]) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setServices

        **void QLowEnergyAdvertisingData::setServices(const
        QList<QBluetoothUuid> & services )**

        Specifies that the service UUIDs in **services** should be advertised.
        If the entire list does not fit into the packet, an incomplete list is
        sent as specified by the Bluetooth Low Energy specification.

        **See also** **services** ().
        """
        ...

    def discoverability(self) -> "QLowEnergyAdvertisingData.Discoverability":
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#discoverability

        **QLowEnergyAdvertisingData::Discoverability
        QLowEnergyAdvertisingData::discoverability() const**

        Returns the discoverability mode of the advertising device. The default
        is **DiscoverabilityNone** .

        **See also** **setDiscoverability** ().
        """
        ...

    def setDiscoverability(
        self, mode: "QLowEnergyAdvertisingData.Discoverability"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setDiscoverability

        **void QLowEnergyAdvertisingData::setDiscoverability(QLowEnergyAdvertisi
        ngData::Discoverability mode )**

        Sets the discoverability type of the advertising device to **mode**.

        **Note:** Discoverability information can only appear in an actual
        advertising data packet. If this object acts as scan response data, a
        call to this function will have no effect on the scan response sent.

        **See also** **discoverability** ().
        """
        ...

    def includePowerLevel(self) -> bool:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#includePowerLevel

        **bool QLowEnergyAdvertisingData::includePowerLevel() const**

        Returns whether to include the device's transmit power level in the
        advertising data. The default is `false`.

        **See also** **setIncludePowerLevel** ().
        """
        ...

    def setIncludePowerLevel(self, doInclude: bool) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setIncludePowerLev
        el

        **void QLowEnergyAdvertisingData::setIncludePowerLevel(bool doInclude
        )**

        Specifies whether to include the device's transmit power level in the
        advertising data. If **doInclude** is `true`, the data will be included,
        otherwise it will not.

        **See also** **includePowerLevel** ().
        """
        ...

    def manufacturerData(self) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#manufacturerData

        **QByteArray QLowEnergyAdvertisingData::manufacturerData() const**

        Returns the manufacturer data. The default is an empty byte array.

        **See also** **setManufacturerData** ().
        """
        ...

    def manufacturerId(self) -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#manufacturerId

        **quint16 QLowEnergyAdvertisingData::manufacturerId() const**

        Returns the manufacturer id. The default is
        **QLowEnergyAdvertisingData::invalidManufacturerId** (), which means the
        data will not be advertised.
        """
        ...

    def setManufacturerData(self, id: int, data: QtCore.QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setManufacturerDat
        a

        **void QLowEnergyAdvertisingData::setManufacturerData(quint16 id , const
        QByteArray & data )**

        Sets the manufacturer id and data. The **id** parameter is a company
        identifier as assigned by the Bluetooth SIG. The **data** parameter is
        an arbitrary value.

        **See also** **manufacturerData** ().
        """
        ...

    @staticmethod
    def invalidManufacturerId() -> int:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#invalidManufacture
        rId

        **[static] quint16 QLowEnergyAdvertisingData::invalidManufacturerId()**

        Returns an invalid manufacturer id. If this value is set as the
        manufacturer id (which it is by default), no manufacturer data will be
        present in the advertising data.
        """
        ...

    def localName(self) -> str:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#localName

        **QString QLowEnergyAdvertisingData::localName() const**

        Returns the name of the local device that is to be advertised.

        **See also** **setLocalName** ().
        """
        ...

    def setLocalName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qlowenergyadvertisingdata.html#setLocalName

        **void QLowEnergyAdvertisingData::setLocalName(const QString & name )**

        Specifies that **name** should be broadcast as the name of the device.
        If the full name does not fit into the advertising data packet, an
        abbreviated name is sent, as described by the Bluetooth Low Energy
        specification.

        On Android, the local name cannot be changed. Android always uses the
        device name. If this local name is not empty, the Android implementation
        includes the device name in the advertisement packet; otherwise the
        device name is omitted from the advertisement packet.

        **See also** **localName** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QOffscreenSurface(QtCore.QObject, QSurface):
    """
    https://doc.qt.io/qt-6/qoffscreensurface.html

    **Detailed Description**

    QOffscreenSurface is intended to be used with **QOpenGLContext**  to allow
    rendering with OpenGL in an arbitrary thread without the need to create a
    **QWindow** .

    Even though the surface is typically renderable, the surface's pixels are
    not accessible. QOffscreenSurface should only be used to create OpenGL
    resources such as textures or framebuffer objects.

    An application will typically use QOffscreenSurface to perform some time-
    consuming tasks in a separate thread in order to avoid stalling the main
    rendering thread. Resources created in the QOffscreenSurface's context can
    be shared with the main OpenGL context. Some common use cases are
    asynchronous texture uploads or rendering into a
    **QOpenGLFramebufferObject** .

    How the offscreen surface is implemented depends on the underlying platform,
    but it will typically use a pixel buffer (pbuffer). If the platform doesn't
    implement or support offscreen surfaces, QOffscreenSurface will use an
    invisible **QWindow**  internally.

    **Note:** Due to the fact that QOffscreenSurface is backed by a **QWindow**
    on some platforms, cross-platform applications must ensure that **create**
    () is only called on the main (GUI) thread. The QOffscreenSurface is then
    safe to be used with **makeCurrent** () on other threads, but the
    initialization and destruction must always happen on the main (GUI) thread.

    **Note:** In order to create an offscreen surface that is guaranteed to be
    compatible with a given context and window, make sure to set the format to
    the context's or the window's actual format, that is, the **QSurfaceFormat**
    returned from **QOpenGLContext::format** () or **QWindow::format** ()
    **after the context or window has been created**. Passing the format
    returned from **QWindow::requestedFormat** () to **setFormat** () may result
    in an incompatible offscreen surface since the underlying windowing system
    interface may offer a different set of configurations for window and pbuffer
    surfaces.

    **Note:** Some platforms may utilize a surfaceless context extension (for
    example EGL_KHR_surfaceless_context) when available. In this case there will
    be no underlying native surface. For the use cases of QOffscreenSurface
    (rendering to FBOs, texture upload) this is not a problem.
    """

    def __init__(
        self,
        screen: typing.Optional["QScreen"] = ...,
        parent: typing.Optional[QtCore.QObject] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#QOffscreenSurface

        **[since 5.10] QOffscreenSurface::QOffscreenSurface(QScreen *
        targetScreen = nullptr, QObject * parent = nullptr)**

        Creates an offscreen surface for the **targetScreen** with the given
        **parent**.

        The underlying platform surface is not created until **create** () is
        called.

        This function was introduced in Qt 5.10.

        **See also** **setScreen** () and **create** ().
        """
        ...

    def setScreen(self, screen: "QScreen") -> None:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#setScreen

        **void QOffscreenSurface::setScreen(QScreen * newScreen )**

        Sets the screen to which the offscreen surface is connected.

        If the offscreen surface has been created, it will be recreated on the
        **newScreen**.

        **See also** **screen** ().
        """
        ...

    def screen(self) -> "QScreen":
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#screen

        **QScreen *QOffscreenSurface::screen() const**

        Returns the screen to which the offscreen surface is connected.

        **See also** **setScreen** ().
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#size

        **[override virtual] QSize QOffscreenSurface::size() const**

        Reimplements: **QSurface::size() const** .

        Returns the size of the offscreen surface.
        """
        ...

    def requestedFormat(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#requestedFormat

        **QSurfaceFormat QOffscreenSurface::requestedFormat() const**

        Returns the requested surfaceformat of this offscreen surface.

        If the requested format was not supported by the platform
        implementation, the requestedFormat will differ from the actual
        offscreen surface format.

        This is the value set with **setFormat** ().

        **See also** **setFormat** () and **format** ().
        """
        ...

    def format(self) -> "QSurfaceFormat":
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#format

        **[override virtual] QSurfaceFormat QOffscreenSurface::format() const**

        Reimplements: **QSurface::format() const** .

        Returns the actual format of this offscreen surface.

        After the offscreen surface has been created, this function will return
        the actual surface format of the surface. It might differ from the
        requested format if the requested format could not be fulfilled by the
        platform.

        **See also** **setFormat** (), **create** (), and **requestedFormat**
        ().
        """
        ...

    def setFormat(self, format: "QSurfaceFormat") -> None:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#setFormat

        **void QOffscreenSurface::setFormat(const QSurfaceFormat & format )**

        Sets the offscreen surface **format**.

        The surface format will be resolved in the **create** () function.
        Calling this function after **create** () will not re-resolve the
        surface format of the native surface.

        **See also** **format** (), **create** (), and **destroy** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#isValid

        **bool QOffscreenSurface::isValid() const**

        Returns `true` if this offscreen surface is valid; otherwise returns
        `false`.

        The offscreen surface is valid if the platform resources have been
        successfully allocated.

        **See also** **create** ().
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#destroy

        **void QOffscreenSurface::destroy()**

        Releases the native platform resources associated with this offscreen
        surface.

        **See also** **create** ().
        """
        ...

    def create(self) -> None:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#create

        **void QOffscreenSurface::create()**

        Allocates the platform resources associated with the offscreen surface.

        It is at this point that the surface format set using **setFormat** ()
        gets resolved into an actual native surface.

        Call **destroy** () to free the platform resources if necessary.

        **Note:** Some platforms require this function to be called on the main
        (GUI) thread.

        **See also** **destroy** ().
        """
        ...

    def surfaceType(self) -> QSurface.SurfaceType:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#surfaceType

        **[override virtual] QSurface::SurfaceType
        QOffscreenSurface::surfaceType() const**

        Reimplements: **QSurface::surfaceType() const** .

        Returns the surface type of the offscreen surface.

        The surface type of an offscreen surface is always
        **QSurface::OpenGLSurface** .
        """
        ...

    @property
    def screenChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qoffscreensurface.html#screenChanged

        **[signal] void QOffscreenSurface::screenChanged(QScreen * screen )**

        This signal is emitted when an offscreen surface's **screen** changes,
        either by being set explicitly with **setScreen** (), or automatically
        when the window's screen is removed.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QLibraryInfo(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qlibraryinfo.html

    **Detailed Description**

    Many pieces of information are established when Qt is configured and built.
    This class provides an abstraction for accessing that information. By using
    the static functions of this class, an application can obtain information
    about the instance of the Qt library which the application is using at run-
    time.

    You can also use a `qt.conf` file to override the hard-coded paths that are
    compiled into the Qt library. For more information, see the **Using
    qt.conf**  documentation.

    **See also** **QSysInfo**  and **Using qt.conf** .
    """

    class LibraryPath(enum.Enum):
        PrefixPath: QLibraryInfo = ...
        DocumentationPath: QLibraryInfo = ...
        HeadersPath: QLibraryInfo = ...
        LibrariesPath: QLibraryInfo = ...
        LibraryExecutablesPath: QLibraryInfo = ...
        BinariesPath: QLibraryInfo = ...
        PluginsPath: QLibraryInfo = ...
        Qml2ImportsPath: QLibraryInfo = ...
        ArchDataPath: QLibraryInfo = ...
        DataPath: QLibraryInfo = ...
        TranslationsPath: QLibraryInfo = ...
        ExamplesPath: QLibraryInfo = ...
        TestsPath: QLibraryInfo = ...
        SettingsPath: QLibraryInfo = ...
        QmlImportsPath: QLibraryInfo = ...

    def __init__(self, a0: "QLibraryInfo") -> None:
        ...

    @staticmethod
    def version() -> "QVersionNumber":
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#version

        **[static, since 5.8] QVersionNumber QLibraryInfo::version()**

        Returns the version of the Qt library.

        This function was introduced in Qt 5.8.

        **See also** **qVersion** ().
        """
        ...

    @staticmethod
    def path(p: "QLibraryInfo.LibraryPath") -> str:
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#path

        **[static, since 6.0] QString
        QLibraryInfo::path(QLibraryInfo::LibraryPath p )**

        Returns the path specified by **p**.

        This function was introduced in Qt 6.0.
        """
        ...

    @staticmethod
    def isDebugBuild() -> bool:
        """
        https://doc.qt.io/qt-6/qlibraryinfo.html#isDebugBuild

        **[static, since 5.0] bool QLibraryInfo::isDebugBuild()**

        Returns `true` if this build of Qt was built with debugging enabled, or
        false if it was built in release mode.

        This function was introduced in Qt 5.0.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6.QtWidgets import *
import enum


class QStyleHintReturnMask(QStyleHintReturn):
    """
    https://doc.qt.io/qt-6/qstylehintreturnmask.html

    **Detailed Description**
    """

    class StyleOptionVersion(enum.Enum):
        Version: QStyleHintReturnMask = ...

    class StyleOptionType(enum.Enum):
        Type: QStyleHintReturnMask = ...

    region: QtGui = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturnmask.html#QStyleHintReturnMask

        **QStyleHintReturnMask::QStyleHintReturnMask()**

        Constructs a QStyleHintReturnMask. The member variables are initialized
        to default values.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QStyleHintReturnMask") -> None:
        """
        https://doc.qt.io/qt-6/qstylehintreturnmask.html#QStyleHintReturnMask

        **QStyleHintReturnMask::QStyleHintReturnMask()**

        Constructs a QStyleHintReturnMask. The member variables are initialized
        to default values.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQuick import *


class QQuickFramebufferObject(QQuickItem):
    """
    https://doc.qt.io/qt-6/qquickframebufferobject.html

    **Detailed Description**

    **Warning:** This class is only functional when Qt Quick is rendering via
    OpenGL. It is not compatible with other graphics APIs, such as Vulkan or
    Metal. It should be treated as a legacy class that is only present in order
    to enable Qt 5 applications to function without source compatibility breaks
    as long as they tie themselves to OpenGL.

    On most platforms, the rendering will occur on a **dedicated thread** . For
    this reason, the QQuickFramebufferObject class enforces a strict separation
    between the item implementation and the FBO rendering. All item logic, such
    as properties and UI-related helper functions needed by QML should be
    located in a QQuickFramebufferObject class subclass. Everything that relates
    to rendering must be located in the **QQuickFramebufferObject::Renderer**
    class.

    To avoid race conditions and read/write issues from two threads it is
    important that the renderer and the item never read or write shared
    variables. Communication between the item and the renderer should primarily
    happen via the **QQuickFramebufferObject::Renderer::synchronize** ()
    function. This function will be called on the render thread while the GUI
    thread is blocked.

    Using queued connections or events for communication between item and
    renderer is also possible.

    Both the Renderer and the FBO are memory managed internally.

    To render into the FBO, the user should subclass the Renderer class and
    reimplement its **Renderer::render** () function. The Renderer subclass is
    returned from **createRenderer** ().

    The size of the FBO will by default adapt to the size of the item. If a
    fixed size is preferred, set **textureFollowsItemSize**  to `false` and
    return a texture of your choosing from
    **QQuickFramebufferObject::Renderer::createFramebufferObject** ().

    Starting Qt 5.4, the QQuickFramebufferObject class is a **texture provider**
    and can be used directly in **ShaderEffects**  and other classes that
    consume texture providers.

    **See also** **Scene Graph - Rendering FBOs**  and **Scene Graph and
    Rendering** .
    """

    class Renderer(PyQt6.sip.wrapper):
        try:
            from PyQt6.QtOpenGL import QOpenGLFramebufferObject
        except ImportError:
            pass

        @typing.overload
        def __init__(self) -> None:
            ...

        @typing.overload
        def __init__(self, a0: "QQuickFramebufferObject.Renderer") -> None:
            ...

        def invalidateFramebufferObject(self) -> None:
            ...

        def update(self) -> None:
            ...

        def framebufferObject(self) -> QOpenGLFramebufferObject:
            ...

        def synchronize(self, a0: "QQuickFramebufferObject") -> None:
            ...

        def createFramebufferObject(
            self, size: QtCore.QSize
        ) -> QOpenGLFramebufferObject:
            ...

        def render(self) -> None:
            ...

    def __init__(self, parent: typing.Optional[QQuickItem] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#QQuickFramebufferObj
        ect

        **QQuickFramebufferObject::QQuickFramebufferObject(QQuickItem * parent =
        nullptr)**

        Constructs a new QQuickFramebufferObject with parent **parent**.
        """
        ...

    def setMirrorVertically(self, enable: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#mirrorVertically-
        prop

        **[since 5.6] mirrorVertically : bool**

        This property controls if the size of the FBO's contents should be
        mirrored vertically when drawing. This allows easy integration of third-
        party rendering code that does not follow the standard expectations.

        The default value is `false`.

        This property was introduced in Qt 5.6.

        **Access functions:**

        bool **mirrorVertically** () const
        void **setMirrorVertically** (bool
        **enable** )

        **Notifier signal:**

        void **mirrorVerticallyChanged** (bool)
        """
        ...

    def mirrorVertically(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#mirrorVertically-
        prop

        **[since 5.6] mirrorVertically : bool**

        This property controls if the size of the FBO's contents should be
        mirrored vertically when drawing. This allows easy integration of third-
        party rendering code that does not follow the standard expectations.

        The default value is `false`.

        This property was introduced in Qt 5.6.

        **Access functions:**

        bool **mirrorVertically** () const
        void **setMirrorVertically** (bool
        **enable** )

        **Notifier signal:**

        void **mirrorVerticallyChanged** (bool)
        """
        ...

    def releaseResources(self) -> None:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#releaseResources

        **[override virtual] void QQuickFramebufferObject::releaseResources()**

        Reimplements: **QQuickItem::releaseResources** ().
        """
        ...

    def textureProvider(self) -> "QSGTextureProvider":
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#textureProvider

        **[override virtual] QSGTextureProvider
        *QQuickFramebufferObject::textureProvider() const**

        Reimplements: **QQuickItem::textureProvider() const** .
        """
        ...

    def isTextureProvider(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#isTextureProvider

        **[override virtual] bool QQuickFramebufferObject::isTextureProvider()
        const**

        Reimplements: **QQuickItem::isTextureProvider() const** .
        """
        ...

    def updatePaintNode(
        self, a0: "QSGNode", a1: QQuickItem.UpdatePaintNodeData
    ) -> "QSGNode":
        ...

    def geometryChange(
        self, newGeometry: QtCore.QRectF, oldGeometry: QtCore.QRectF
    ) -> None:
        ...

    def createRenderer(self) -> "QQuickFramebufferObject.Renderer":
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#createRenderer

        **[pure virtual] QQuickFramebufferObject::Renderer
        *QQuickFramebufferObject::createRenderer() const**

        Reimplement this function to create a renderer used to render into the
        FBO.

        This function will be called on the rendering thread while the GUI
        thread is blocked.
        """
        ...

    def setTextureFollowsItemSize(self, follows: bool) -> None:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#textureFollowsItemSi
        ze-prop

        **textureFollowsItemSize : bool**

        This property controls if the size of the FBO's texture should follow
        the dimensions of the **QQuickFramebufferObject**  item. When this
        property is false, the FBO will be created once the first time it is
        displayed. If it is set to true, the FBO will be recreated every time
        the dimensions of the item change.

        The default value is `true`.

        **Access functions:**

        bool **textureFollowsItemSize** () const
        void
        **setTextureFollowsItemSize** (bool **follows** )

        **Notifier signal:**

        void **textureFollowsItemSizeChanged** (bool)

        **Member Function Documentation**
        """
        ...

    def textureFollowsItemSize(self) -> bool:
        """
        https://doc.qt.io/qt-6/qquickframebufferobject.html#textureFollowsItemSi
        ze-prop

        **textureFollowsItemSize : bool**

        This property controls if the size of the FBO's texture should follow
        the dimensions of the **QQuickFramebufferObject**  item. When this
        property is false, the FBO will be created once the first time it is
        displayed. If it is set to true, the FBO will be recreated every time
        the dimensions of the item change.

        The default value is `true`.

        **Access functions:**

        bool **textureFollowsItemSize** () const
        void
        **setTextureFollowsItemSize** (bool **follows** )

        **Notifier signal:**

        void **textureFollowsItemSizeChanged** (bool)

        **Member Function Documentation**
        """
        ...

    @property
    def mirrorVerticallyChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def textureFollowsItemSizeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QRegularExpressionMatch(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qregularexpressionmatch.html

    **Detailed Description**

    A QRegularExpressionMatch object can be obtained by calling the
    **QRegularExpression::match** () function, or as a single result of a global
    match from a **QRegularExpressionMatchIterator** .

    The success or the failure of a match attempt can be inspected by calling
    the **hasMatch** () function. QRegularExpressionMatch also reports a
    successful partial match through the **hasPartialMatch** () function.

    In addition, QRegularExpressionMatch returns the substrings captured by the
    capturing groups in the pattern string. The implicit capturing group with
    index 0 captures the result of the whole match. The **captured** () function
    returns each substring captured, either by the capturing group's index or by
    its name:

    **QRegularExpression**  re("(\\\\d\\\\d) (?<name>\\\\w+)");
    **QRegularExpressionMatch**  match = re.match("23 Jordan");
        if
    (match.hasMatch()) {
            **QString**  number = match.captured(1); //
    first == "23"
            **QString**  name = match.captured("name"); // name ==
    "Jordan"
        }

    For each captured substring it is possible to query its starting and ending
    offsets in the subject string by calling the **capturedStart** () and the
    **capturedEnd** () function, respectively. The length of each captured
    substring is available using the **capturedLength** () function.

    The convenience function **capturedTexts** () will return **all** the
    captured substrings at once (including the substring matched by the entire
    pattern) in the order they have been captured by capturing groups; that is,
    `captured(i) == capturedTexts().at(i)`.

    You can retrieve the **QRegularExpression**  object the subject string was
    matched against by calling the **regularExpression** () function; the match
    type and the match options are available as well by calling the
    **matchType** () and the **matchOptions** () respectively.

    Please refer to the **QRegularExpression**  documentation for more
    information about the Qt regular expression classes.

    **See also** **QRegularExpression** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#QRegularExpressionMa
        tch

        **[since 5.1] QRegularExpressionMatch::QRegularExpressionMatch()**

        Constructs a valid, empty QRegularExpressionMatch object. The regular
        expression is set to a default-constructed one; the match type to
        **QRegularExpression::NoMatch**  and the match options to
        **QRegularExpression::NoMatchOption** .

        The object will report no match through the **hasMatch** () and the
        **hasPartialMatch** () member functions.

        This function was introduced in Qt 5.1.
        """
        ...

    @typing.overload
    def __init__(self, match: "QRegularExpressionMatch") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#QRegularExpressionMa
        tch-1

        **QRegularExpressionMatch::QRegularExpressionMatch(const
        QRegularExpressionMatch & match )**

        Constructs a match result by copying the result of the given **match**.

        **See also** **operator=** ().
        """
        ...

    @typing.overload
    def capturedEnd(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedEnd

        **qsizetype QRegularExpressionMatch::capturedEnd(int nth = 0) const**

        Returns the offset inside the subject string immediately after the
        ending position of the substring captured by the **nth** capturing
        group. If the **nth** capturing group did not capture a string or
        doesn't exist, returns -1.

        **See also** **capturedStart** (), **capturedLength** (), and
        **captured** ().
        """
        ...

    @typing.overload
    def capturedEnd(self, nth: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedEnd-1

        **qsizetype QRegularExpressionMatch::capturedEnd(const QString & name )
        const**

        Returns the offset inside the subject string immediately after the
        ending position of the substring captured by the capturing group named
        **name**. If the capturing group named **name** did not capture a string
        or doesn't exist, returns -1.

        **See also** **capturedStart** (), **capturedLength** (), and
        **captured** ().
        """
        ...

    @typing.overload
    def capturedLength(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedLength

        **qsizetype QRegularExpressionMatch::capturedLength(int nth = 0) const**

        Returns the length of the substring captured by the **nth** capturing
        group.

        **Note:** This function returns 0 if the **nth** capturing group did not
        capture a string or doesn't exist.

        **See also** **capturedStart** (), **capturedEnd** (), and **captured**
        ().
        """
        ...

    @typing.overload
    def capturedLength(self, nth: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedLength-1

        **qsizetype QRegularExpressionMatch::capturedLength(const QString & name
        ) const**

        Returns the length of the substring captured by the capturing group
        named **name**.

        **Note:** This function returns 0 if the capturing group named **name**
        did not capture a string or doesn't exist.

        **See also** **capturedStart** (), **capturedEnd** (), and **captured**
        ().
        """
        ...

    @typing.overload
    def capturedStart(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedStart

        **qsizetype QRegularExpressionMatch::capturedStart(int nth = 0) const**

        Returns the offset inside the subject string corresponding to the
        starting position of the substring captured by the **nth** capturing
        group. If the **nth** capturing group did not capture a string or
        doesn't exist, returns -1.

        **See also** **capturedEnd** (), **capturedLength** (), and **captured**
        ().
        """
        ...

    @typing.overload
    def capturedStart(self, nth: int = ...) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedStart-1

        **qsizetype QRegularExpressionMatch::capturedStart(const QString & name
        ) const**

        Returns the offset inside the subject string corresponding to the
        starting position of the substring captured by the capturing group named
        **name**. If the capturing group named **name** did not capture a string
        or doesn't exist, returns -1.

        **See also** **capturedEnd** (), **capturedLength** (), and **captured**
        ().
        """
        ...

    def capturedTexts(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#capturedTexts

        **QStringList QRegularExpressionMatch::capturedTexts() const**

        Returns a list of all strings captured by capturing groups, in the order
        the groups themselves appear in the pattern string. The list includes
        the implicit capturing group number 0, capturing the substring matched
        by the entire pattern.
        """
        ...

    @typing.overload
    def captured(self, nth: int = ...) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#captured

        **QString QRegularExpressionMatch::captured(int nth = 0) const**

        Returns the substring captured by the **nth** capturing group.

        If the **nth** capturing group did not capture a string, or if there is
        no such capturing group, returns a null **QString** .

        **Note:** The implicit capturing group number 0 captures the substring
        matched by the entire pattern.

        **See also** **capturedView** (), **lastCapturedIndex** (),
        **capturedStart** (), **capturedEnd** (), **capturedLength** (), and
        **QString::isNull** ().
        """
        ...

    @typing.overload
    def captured(self, name: str) -> str:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#captured-1

        **QString QRegularExpressionMatch::captured(const QString & name )
        const**

        Returns the substring captured by the capturing group named **name**.

        If the named capturing group **name** did not capture a string, or if
        there is no capturing group named **name** , returns a null **QString**
        .

        **See also** **capturedView** (), **capturedStart** (), **capturedEnd**
        (), **capturedLength** (), and **QString::isNull** ().
        """
        ...

    def lastCapturedIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#lastCapturedIndex

        **int QRegularExpressionMatch::lastCapturedIndex() const**

        Returns the index of the last capturing group that captured something,
        including the implicit capturing group 0. This can be used to extract
        all the substrings that were captured:

        **QRegularExpressionMatch**  match = re.match(string);
            for (int i =
        0; i <= match.lastCapturedIndex(); ++i) {
                **QString**  captured
        = match.captured(i);
                // ...
            }

        Note that some of the capturing groups with an index less than
        lastCapturedIndex() could have not matched, and therefore captured
        nothing.

        If the regular expression did not match, this function returns -1.

        **See also** **captured** (), **capturedStart** (), **capturedEnd** (),
        and **capturedLength** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#isValid

        **bool QRegularExpressionMatch::isValid() const**

        Returns `true` if the match object was obtained as a result from the
        **QRegularExpression::match** () function invoked on a valid
        **QRegularExpression**  object; returns `false` if the
        **QRegularExpression**  was invalid.

        **See also** **QRegularExpression::match** () and
        **QRegularExpression::isValid** ().
        """
        ...

    def hasPartialMatch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#hasPartialMatch

        **bool QRegularExpressionMatch::hasPartialMatch() const**

        Returns `true` if the regular expression partially matched against the
        subject string, or false otherwise.

        **Note:** Only a match that explicitly used the one of the partial match
        types can yield a partial match. Still, if such a match succeeds
        totally, this function will return false, while **hasMatch** () will
        return true.

        **See also** **QRegularExpression::match** (),
        **QRegularExpression::MatchType** , and **hasMatch** ().
        """
        ...

    def hasMatch(self) -> bool:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#hasMatch

        **bool QRegularExpressionMatch::hasMatch() const**

        Returns `true` if the regular expression matched against the subject
        string, or false otherwise.

        **See also** **QRegularExpression::match** () and **hasPartialMatch**
        ().
        """
        ...

    def matchOptions(self) -> QRegularExpression.MatchOption:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#matchOptions

        **QRegularExpression::MatchOptions
        QRegularExpressionMatch::matchOptions() const**

        Returns the match options that were used to get this
        **QRegularExpressionMatch**  object, that is, the match options that
        were passed to **QRegularExpression::match** () or
        **QRegularExpression::globalMatch** ().

        **See also** **QRegularExpression::match** (), **regularExpression** (),
        and **matchType** ().
        """
        ...

    def matchType(self) -> QRegularExpression.MatchType:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#matchType

        **QRegularExpression::MatchType QRegularExpressionMatch::matchType()
        const**

        Returns the match type that was used to get this
        **QRegularExpressionMatch**  object, that is, the match type that was
        passed to **QRegularExpression::match** () or
        **QRegularExpression::globalMatch** ().

        **See also** **QRegularExpression::match** (), **regularExpression** (),
        and **matchOptions** ().
        """
        ...

    def regularExpression(self) -> QRegularExpression:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#regularExpression

        **QRegularExpression QRegularExpressionMatch::regularExpression()
        const**

        Returns the **QRegularExpression**  object whose match() function
        returned this object.

        **See also** **QRegularExpression::match** (), **matchType** (), and
        **matchOptions** ().
        """
        ...

    def swap(self, match: "QRegularExpressionMatch") -> None:
        """
        https://doc.qt.io/qt-6/qregularexpressionmatch.html#swap

        **void QRegularExpressionMatch::swap(QRegularExpressionMatch & other )**

        Swaps the match result **other** with this match result. This operation
        is very fast and never fails.
        """
        ...
